/***************************************************************************//**
* \file Tx8_PINS.h
* \version 4.0
*
* \brief
*  This file provides constants and parameter values for the pin components
*  buried into SCB Component.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PINS_Tx8_H)
#define CY_SCB_PINS_Tx8_H

#include "cydevice_trm.h"
#include "cyfitter.h"
#include "cytypes.h"


/***************************************
*   Conditional Compilation Parameters
****************************************/

/* Unconfigured pins */
#define Tx8_REMOVE_RX_WAKE_SCL_MOSI_PIN  (1u)
#define Tx8_REMOVE_RX_SCL_MOSI_PIN      (1u)
#define Tx8_REMOVE_TX_SDA_MISO_PIN      (1u)
#define Tx8_REMOVE_SCLK_PIN      (1u)
#define Tx8_REMOVE_SS0_PIN      (1u)
#define Tx8_REMOVE_SS1_PIN                 (1u)
#define Tx8_REMOVE_SS2_PIN                 (1u)
#define Tx8_REMOVE_SS3_PIN                 (1u)

/* Mode defined pins */
#define Tx8_REMOVE_I2C_PINS                (1u)
#define Tx8_REMOVE_SPI_MASTER_PINS         (1u)
#define Tx8_REMOVE_SPI_MASTER_SCLK_PIN     (1u)
#define Tx8_REMOVE_SPI_MASTER_MOSI_PIN     (1u)
#define Tx8_REMOVE_SPI_MASTER_MISO_PIN     (1u)
#define Tx8_REMOVE_SPI_MASTER_SS0_PIN      (1u)
#define Tx8_REMOVE_SPI_MASTER_SS1_PIN      (1u)
#define Tx8_REMOVE_SPI_MASTER_SS2_PIN      (1u)
#define Tx8_REMOVE_SPI_MASTER_SS3_PIN      (1u)
#define Tx8_REMOVE_SPI_SLAVE_PINS          (1u)
#define Tx8_REMOVE_SPI_SLAVE_MOSI_PIN      (1u)
#define Tx8_REMOVE_SPI_SLAVE_MISO_PIN      (1u)
#define Tx8_REMOVE_UART_TX_PIN             (0u)
#define Tx8_REMOVE_UART_RX_TX_PIN          (1u)
#define Tx8_REMOVE_UART_RX_PIN             (1u)
#define Tx8_REMOVE_UART_RX_WAKE_PIN        (1u)
#define Tx8_REMOVE_UART_RTS_PIN            (1u)
#define Tx8_REMOVE_UART_CTS_PIN            (1u)

/* Unconfigured pins */
#define Tx8_RX_WAKE_SCL_MOSI_PIN (0u == Tx8_REMOVE_RX_WAKE_SCL_MOSI_PIN)
#define Tx8_RX_SCL_MOSI_PIN     (0u == Tx8_REMOVE_RX_SCL_MOSI_PIN)
#define Tx8_TX_SDA_MISO_PIN     (0u == Tx8_REMOVE_TX_SDA_MISO_PIN)
#define Tx8_SCLK_PIN     (0u == Tx8_REMOVE_SCLK_PIN)
#define Tx8_SS0_PIN     (0u == Tx8_REMOVE_SS0_PIN)
#define Tx8_SS1_PIN                (0u == Tx8_REMOVE_SS1_PIN)
#define Tx8_SS2_PIN                (0u == Tx8_REMOVE_SS2_PIN)
#define Tx8_SS3_PIN                (0u == Tx8_REMOVE_SS3_PIN)

/* Mode defined pins */
#define Tx8_I2C_PINS               (0u == Tx8_REMOVE_I2C_PINS)
#define Tx8_SPI_MASTER_PINS        (0u == Tx8_REMOVE_SPI_MASTER_PINS)
#define Tx8_SPI_MASTER_SCLK_PIN    (0u == Tx8_REMOVE_SPI_MASTER_SCLK_PIN)
#define Tx8_SPI_MASTER_MOSI_PIN    (0u == Tx8_REMOVE_SPI_MASTER_MOSI_PIN)
#define Tx8_SPI_MASTER_MISO_PIN    (0u == Tx8_REMOVE_SPI_MASTER_MISO_PIN)
#define Tx8_SPI_MASTER_SS0_PIN     (0u == Tx8_REMOVE_SPI_MASTER_SS0_PIN)
#define Tx8_SPI_MASTER_SS1_PIN     (0u == Tx8_REMOVE_SPI_MASTER_SS1_PIN)
#define Tx8_SPI_MASTER_SS2_PIN     (0u == Tx8_REMOVE_SPI_MASTER_SS2_PIN)
#define Tx8_SPI_MASTER_SS3_PIN     (0u == Tx8_REMOVE_SPI_MASTER_SS3_PIN)
#define Tx8_SPI_SLAVE_PINS         (0u == Tx8_REMOVE_SPI_SLAVE_PINS)
#define Tx8_SPI_SLAVE_MOSI_PIN     (0u == Tx8_REMOVE_SPI_SLAVE_MOSI_PIN)
#define Tx8_SPI_SLAVE_MISO_PIN     (0u == Tx8_REMOVE_SPI_SLAVE_MISO_PIN)
#define Tx8_UART_TX_PIN            (0u == Tx8_REMOVE_UART_TX_PIN)
#define Tx8_UART_RX_TX_PIN         (0u == Tx8_REMOVE_UART_RX_TX_PIN)
#define Tx8_UART_RX_PIN            (0u == Tx8_REMOVE_UART_RX_PIN)
#define Tx8_UART_RX_WAKE_PIN       (0u == Tx8_REMOVE_UART_RX_WAKE_PIN)
#define Tx8_UART_RTS_PIN           (0u == Tx8_REMOVE_UART_RTS_PIN)
#define Tx8_UART_CTS_PIN           (0u == Tx8_REMOVE_UART_CTS_PIN)


/***************************************
*             Includes
****************************************/

#if (Tx8_RX_WAKE_SCL_MOSI_PIN)
    #include "Tx8_uart_rx_wake_i2c_scl_spi_mosi.h"
#endif /* (Tx8_RX_SCL_MOSI) */

#if (Tx8_RX_SCL_MOSI_PIN)
    #include "Tx8_uart_rx_i2c_scl_spi_mosi.h"
#endif /* (Tx8_RX_SCL_MOSI) */

#if (Tx8_TX_SDA_MISO_PIN)
    #include "Tx8_uart_tx_i2c_sda_spi_miso.h"
#endif /* (Tx8_TX_SDA_MISO) */

#if (Tx8_SCLK_PIN)
    #include "Tx8_spi_sclk.h"
#endif /* (Tx8_SCLK) */

#if (Tx8_SS0_PIN)
    #include "Tx8_spi_ss0.h"
#endif /* (Tx8_SS0_PIN) */

#if (Tx8_SS1_PIN)
    #include "Tx8_spi_ss1.h"
#endif /* (Tx8_SS1_PIN) */

#if (Tx8_SS2_PIN)
    #include "Tx8_spi_ss2.h"
#endif /* (Tx8_SS2_PIN) */

#if (Tx8_SS3_PIN)
    #include "Tx8_spi_ss3.h"
#endif /* (Tx8_SS3_PIN) */

#if (Tx8_I2C_PINS)
    #include "Tx8_scl.h"
    #include "Tx8_sda.h"
#endif /* (Tx8_I2C_PINS) */

#if (Tx8_SPI_MASTER_PINS)
#if (Tx8_SPI_MASTER_SCLK_PIN)
    #include "Tx8_sclk_m.h"
#endif /* (Tx8_SPI_MASTER_SCLK_PIN) */

#if (Tx8_SPI_MASTER_MOSI_PIN)
    #include "Tx8_mosi_m.h"
#endif /* (Tx8_SPI_MASTER_MOSI_PIN) */

#if (Tx8_SPI_MASTER_MISO_PIN)
    #include "Tx8_miso_m.h"
#endif /*(Tx8_SPI_MASTER_MISO_PIN) */
#endif /* (Tx8_SPI_MASTER_PINS) */

#if (Tx8_SPI_SLAVE_PINS)
    #include "Tx8_sclk_s.h"
    #include "Tx8_ss_s.h"

#if (Tx8_SPI_SLAVE_MOSI_PIN)
    #include "Tx8_mosi_s.h"
#endif /* (Tx8_SPI_SLAVE_MOSI_PIN) */

#if (Tx8_SPI_SLAVE_MISO_PIN)
    #include "Tx8_miso_s.h"
#endif /*(Tx8_SPI_SLAVE_MISO_PIN) */
#endif /* (Tx8_SPI_SLAVE_PINS) */

#if (Tx8_SPI_MASTER_SS0_PIN)
    #include "Tx8_ss0_m.h"
#endif /* (Tx8_SPI_MASTER_SS0_PIN) */

#if (Tx8_SPI_MASTER_SS1_PIN)
    #include "Tx8_ss1_m.h"
#endif /* (Tx8_SPI_MASTER_SS1_PIN) */

#if (Tx8_SPI_MASTER_SS2_PIN)
    #include "Tx8_ss2_m.h"
#endif /* (Tx8_SPI_MASTER_SS2_PIN) */

#if (Tx8_SPI_MASTER_SS3_PIN)
    #include "Tx8_ss3_m.h"
#endif /* (Tx8_SPI_MASTER_SS3_PIN) */

#if (Tx8_UART_TX_PIN)
    #include "Tx8_tx.h"
#endif /* (Tx8_UART_TX_PIN) */

#if (Tx8_UART_RX_TX_PIN)
    #include "Tx8_rx_tx.h"
#endif /* (Tx8_UART_RX_TX_PIN) */

#if (Tx8_UART_RX_PIN)
    #include "Tx8_rx.h"
#endif /* (Tx8_UART_RX_PIN) */

#if (Tx8_UART_RX_WAKE_PIN)
    #include "Tx8_rx_wake.h"
#endif /* (Tx8_UART_RX_WAKE_PIN) */

#if (Tx8_UART_RTS_PIN)
    #include "Tx8_rts.h"
#endif /* (Tx8_UART_RTS_PIN) */

#if (Tx8_UART_CTS_PIN)
    #include "Tx8_cts.h"
#endif /* (Tx8_UART_CTS_PIN) */


/***************************************
*              Registers
***************************************/

#if (Tx8_RX_SCL_MOSI_PIN)
    #define Tx8_RX_SCL_MOSI_HSIOM_REG   (*(reg32 *) Tx8_uart_rx_i2c_scl_spi_mosi__0__HSIOM)
    #define Tx8_RX_SCL_MOSI_HSIOM_PTR   ( (reg32 *) Tx8_uart_rx_i2c_scl_spi_mosi__0__HSIOM)
    
    #define Tx8_RX_SCL_MOSI_HSIOM_MASK      (Tx8_uart_rx_i2c_scl_spi_mosi__0__HSIOM_MASK)
    #define Tx8_RX_SCL_MOSI_HSIOM_POS       (Tx8_uart_rx_i2c_scl_spi_mosi__0__HSIOM_SHIFT)
    #define Tx8_RX_SCL_MOSI_HSIOM_SEL_GPIO  (Tx8_uart_rx_i2c_scl_spi_mosi__0__HSIOM_GPIO)
    #define Tx8_RX_SCL_MOSI_HSIOM_SEL_I2C   (Tx8_uart_rx_i2c_scl_spi_mosi__0__HSIOM_I2C)
    #define Tx8_RX_SCL_MOSI_HSIOM_SEL_SPI   (Tx8_uart_rx_i2c_scl_spi_mosi__0__HSIOM_SPI)
    #define Tx8_RX_SCL_MOSI_HSIOM_SEL_UART  (Tx8_uart_rx_i2c_scl_spi_mosi__0__HSIOM_UART)
    
#elif (Tx8_RX_WAKE_SCL_MOSI_PIN)
    #define Tx8_RX_WAKE_SCL_MOSI_HSIOM_REG   (*(reg32 *) Tx8_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM)
    #define Tx8_RX_WAKE_SCL_MOSI_HSIOM_PTR   ( (reg32 *) Tx8_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM)
    
    #define Tx8_RX_WAKE_SCL_MOSI_HSIOM_MASK      (Tx8_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_MASK)
    #define Tx8_RX_WAKE_SCL_MOSI_HSIOM_POS       (Tx8_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_SHIFT)
    #define Tx8_RX_WAKE_SCL_MOSI_HSIOM_SEL_GPIO  (Tx8_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_GPIO)
    #define Tx8_RX_WAKE_SCL_MOSI_HSIOM_SEL_I2C   (Tx8_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_I2C)
    #define Tx8_RX_WAKE_SCL_MOSI_HSIOM_SEL_SPI   (Tx8_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_SPI)
    #define Tx8_RX_WAKE_SCL_MOSI_HSIOM_SEL_UART  (Tx8_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_UART)    
   
    #define Tx8_RX_WAKE_SCL_MOSI_INTCFG_REG (*(reg32 *) Tx8_uart_rx_wake_i2c_scl_spi_mosi__0__INTCFG)
    #define Tx8_RX_WAKE_SCL_MOSI_INTCFG_PTR ( (reg32 *) Tx8_uart_rx_wake_i2c_scl_spi_mosi__0__INTCFG)
    #define Tx8_RX_WAKE_SCL_MOSI_INTCFG_TYPE_POS  (Tx8_uart_rx_wake_i2c_scl_spi_mosi__SHIFT)
    #define Tx8_RX_WAKE_SCL_MOSI_INTCFG_TYPE_MASK ((uint32) Tx8_INTCFG_TYPE_MASK << \
                                                                           Tx8_RX_WAKE_SCL_MOSI_INTCFG_TYPE_POS)
#else
    /* None of pins Tx8_RX_SCL_MOSI_PIN or Tx8_RX_WAKE_SCL_MOSI_PIN present.*/
#endif /* (Tx8_RX_SCL_MOSI_PIN) */

#if (Tx8_TX_SDA_MISO_PIN)
    #define Tx8_TX_SDA_MISO_HSIOM_REG   (*(reg32 *) Tx8_uart_tx_i2c_sda_spi_miso__0__HSIOM)
    #define Tx8_TX_SDA_MISO_HSIOM_PTR   ( (reg32 *) Tx8_uart_tx_i2c_sda_spi_miso__0__HSIOM)
    
    #define Tx8_TX_SDA_MISO_HSIOM_MASK      (Tx8_uart_tx_i2c_sda_spi_miso__0__HSIOM_MASK)
    #define Tx8_TX_SDA_MISO_HSIOM_POS       (Tx8_uart_tx_i2c_sda_spi_miso__0__HSIOM_SHIFT)
    #define Tx8_TX_SDA_MISO_HSIOM_SEL_GPIO  (Tx8_uart_tx_i2c_sda_spi_miso__0__HSIOM_GPIO)
    #define Tx8_TX_SDA_MISO_HSIOM_SEL_I2C   (Tx8_uart_tx_i2c_sda_spi_miso__0__HSIOM_I2C)
    #define Tx8_TX_SDA_MISO_HSIOM_SEL_SPI   (Tx8_uart_tx_i2c_sda_spi_miso__0__HSIOM_SPI)
    #define Tx8_TX_SDA_MISO_HSIOM_SEL_UART  (Tx8_uart_tx_i2c_sda_spi_miso__0__HSIOM_UART)
#endif /* (Tx8_TX_SDA_MISO_PIN) */

#if (Tx8_SCLK_PIN)
    #define Tx8_SCLK_HSIOM_REG   (*(reg32 *) Tx8_spi_sclk__0__HSIOM)
    #define Tx8_SCLK_HSIOM_PTR   ( (reg32 *) Tx8_spi_sclk__0__HSIOM)
    
    #define Tx8_SCLK_HSIOM_MASK      (Tx8_spi_sclk__0__HSIOM_MASK)
    #define Tx8_SCLK_HSIOM_POS       (Tx8_spi_sclk__0__HSIOM_SHIFT)
    #define Tx8_SCLK_HSIOM_SEL_GPIO  (Tx8_spi_sclk__0__HSIOM_GPIO)
    #define Tx8_SCLK_HSIOM_SEL_I2C   (Tx8_spi_sclk__0__HSIOM_I2C)
    #define Tx8_SCLK_HSIOM_SEL_SPI   (Tx8_spi_sclk__0__HSIOM_SPI)
    #define Tx8_SCLK_HSIOM_SEL_UART  (Tx8_spi_sclk__0__HSIOM_UART)
#endif /* (Tx8_SCLK_PIN) */

#if (Tx8_SS0_PIN)
    #define Tx8_SS0_HSIOM_REG   (*(reg32 *) Tx8_spi_ss0__0__HSIOM)
    #define Tx8_SS0_HSIOM_PTR   ( (reg32 *) Tx8_spi_ss0__0__HSIOM)
    
    #define Tx8_SS0_HSIOM_MASK      (Tx8_spi_ss0__0__HSIOM_MASK)
    #define Tx8_SS0_HSIOM_POS       (Tx8_spi_ss0__0__HSIOM_SHIFT)
    #define Tx8_SS0_HSIOM_SEL_GPIO  (Tx8_spi_ss0__0__HSIOM_GPIO)
    #define Tx8_SS0_HSIOM_SEL_I2C   (Tx8_spi_ss0__0__HSIOM_I2C)
    #define Tx8_SS0_HSIOM_SEL_SPI   (Tx8_spi_ss0__0__HSIOM_SPI)
#if !(Tx8_CY_SCBIP_V0 || Tx8_CY_SCBIP_V1)
    #define Tx8_SS0_HSIOM_SEL_UART  (Tx8_spi_ss0__0__HSIOM_UART)
#endif /* !(Tx8_CY_SCBIP_V0 || Tx8_CY_SCBIP_V1) */
#endif /* (Tx8_SS0_PIN) */

#if (Tx8_SS1_PIN)
    #define Tx8_SS1_HSIOM_REG  (*(reg32 *) Tx8_spi_ss1__0__HSIOM)
    #define Tx8_SS1_HSIOM_PTR  ( (reg32 *) Tx8_spi_ss1__0__HSIOM)
    
    #define Tx8_SS1_HSIOM_MASK     (Tx8_spi_ss1__0__HSIOM_MASK)
    #define Tx8_SS1_HSIOM_POS      (Tx8_spi_ss1__0__HSIOM_SHIFT)
    #define Tx8_SS1_HSIOM_SEL_GPIO (Tx8_spi_ss1__0__HSIOM_GPIO)
    #define Tx8_SS1_HSIOM_SEL_I2C  (Tx8_spi_ss1__0__HSIOM_I2C)
    #define Tx8_SS1_HSIOM_SEL_SPI  (Tx8_spi_ss1__0__HSIOM_SPI)
#endif /* (Tx8_SS1_PIN) */

#if (Tx8_SS2_PIN)
    #define Tx8_SS2_HSIOM_REG     (*(reg32 *) Tx8_spi_ss2__0__HSIOM)
    #define Tx8_SS2_HSIOM_PTR     ( (reg32 *) Tx8_spi_ss2__0__HSIOM)
    
    #define Tx8_SS2_HSIOM_MASK     (Tx8_spi_ss2__0__HSIOM_MASK)
    #define Tx8_SS2_HSIOM_POS      (Tx8_spi_ss2__0__HSIOM_SHIFT)
    #define Tx8_SS2_HSIOM_SEL_GPIO (Tx8_spi_ss2__0__HSIOM_GPIO)
    #define Tx8_SS2_HSIOM_SEL_I2C  (Tx8_spi_ss2__0__HSIOM_I2C)
    #define Tx8_SS2_HSIOM_SEL_SPI  (Tx8_spi_ss2__0__HSIOM_SPI)
#endif /* (Tx8_SS2_PIN) */

#if (Tx8_SS3_PIN)
    #define Tx8_SS3_HSIOM_REG     (*(reg32 *) Tx8_spi_ss3__0__HSIOM)
    #define Tx8_SS3_HSIOM_PTR     ( (reg32 *) Tx8_spi_ss3__0__HSIOM)
    
    #define Tx8_SS3_HSIOM_MASK     (Tx8_spi_ss3__0__HSIOM_MASK)
    #define Tx8_SS3_HSIOM_POS      (Tx8_spi_ss3__0__HSIOM_SHIFT)
    #define Tx8_SS3_HSIOM_SEL_GPIO (Tx8_spi_ss3__0__HSIOM_GPIO)
    #define Tx8_SS3_HSIOM_SEL_I2C  (Tx8_spi_ss3__0__HSIOM_I2C)
    #define Tx8_SS3_HSIOM_SEL_SPI  (Tx8_spi_ss3__0__HSIOM_SPI)
#endif /* (Tx8_SS3_PIN) */

#if (Tx8_I2C_PINS)
    #define Tx8_SCL_HSIOM_REG  (*(reg32 *) Tx8_scl__0__HSIOM)
    #define Tx8_SCL_HSIOM_PTR  ( (reg32 *) Tx8_scl__0__HSIOM)
    
    #define Tx8_SCL_HSIOM_MASK     (Tx8_scl__0__HSIOM_MASK)
    #define Tx8_SCL_HSIOM_POS      (Tx8_scl__0__HSIOM_SHIFT)
    #define Tx8_SCL_HSIOM_SEL_GPIO (Tx8_sda__0__HSIOM_GPIO)
    #define Tx8_SCL_HSIOM_SEL_I2C  (Tx8_sda__0__HSIOM_I2C)
    
    #define Tx8_SDA_HSIOM_REG  (*(reg32 *) Tx8_sda__0__HSIOM)
    #define Tx8_SDA_HSIOM_PTR  ( (reg32 *) Tx8_sda__0__HSIOM)
    
    #define Tx8_SDA_HSIOM_MASK     (Tx8_sda__0__HSIOM_MASK)
    #define Tx8_SDA_HSIOM_POS      (Tx8_sda__0__HSIOM_SHIFT)
    #define Tx8_SDA_HSIOM_SEL_GPIO (Tx8_sda__0__HSIOM_GPIO)
    #define Tx8_SDA_HSIOM_SEL_I2C  (Tx8_sda__0__HSIOM_I2C)
#endif /* (Tx8_I2C_PINS) */

#if (Tx8_SPI_SLAVE_PINS)
    #define Tx8_SCLK_S_HSIOM_REG   (*(reg32 *) Tx8_sclk_s__0__HSIOM)
    #define Tx8_SCLK_S_HSIOM_PTR   ( (reg32 *) Tx8_sclk_s__0__HSIOM)
    
    #define Tx8_SCLK_S_HSIOM_MASK      (Tx8_sclk_s__0__HSIOM_MASK)
    #define Tx8_SCLK_S_HSIOM_POS       (Tx8_sclk_s__0__HSIOM_SHIFT)
    #define Tx8_SCLK_S_HSIOM_SEL_GPIO  (Tx8_sclk_s__0__HSIOM_GPIO)
    #define Tx8_SCLK_S_HSIOM_SEL_SPI   (Tx8_sclk_s__0__HSIOM_SPI)
    
    #define Tx8_SS0_S_HSIOM_REG    (*(reg32 *) Tx8_ss0_s__0__HSIOM)
    #define Tx8_SS0_S_HSIOM_PTR    ( (reg32 *) Tx8_ss0_s__0__HSIOM)
    
    #define Tx8_SS0_S_HSIOM_MASK       (Tx8_ss0_s__0__HSIOM_MASK)
    #define Tx8_SS0_S_HSIOM_POS        (Tx8_ss0_s__0__HSIOM_SHIFT)
    #define Tx8_SS0_S_HSIOM_SEL_GPIO   (Tx8_ss0_s__0__HSIOM_GPIO)  
    #define Tx8_SS0_S_HSIOM_SEL_SPI    (Tx8_ss0_s__0__HSIOM_SPI)
#endif /* (Tx8_SPI_SLAVE_PINS) */

#if (Tx8_SPI_SLAVE_MOSI_PIN)
    #define Tx8_MOSI_S_HSIOM_REG   (*(reg32 *) Tx8_mosi_s__0__HSIOM)
    #define Tx8_MOSI_S_HSIOM_PTR   ( (reg32 *) Tx8_mosi_s__0__HSIOM)
    
    #define Tx8_MOSI_S_HSIOM_MASK      (Tx8_mosi_s__0__HSIOM_MASK)
    #define Tx8_MOSI_S_HSIOM_POS       (Tx8_mosi_s__0__HSIOM_SHIFT)
    #define Tx8_MOSI_S_HSIOM_SEL_GPIO  (Tx8_mosi_s__0__HSIOM_GPIO)
    #define Tx8_MOSI_S_HSIOM_SEL_SPI   (Tx8_mosi_s__0__HSIOM_SPI)
#endif /* (Tx8_SPI_SLAVE_MOSI_PIN) */

#if (Tx8_SPI_SLAVE_MISO_PIN)
    #define Tx8_MISO_S_HSIOM_REG   (*(reg32 *) Tx8_miso_s__0__HSIOM)
    #define Tx8_MISO_S_HSIOM_PTR   ( (reg32 *) Tx8_miso_s__0__HSIOM)
    
    #define Tx8_MISO_S_HSIOM_MASK      (Tx8_miso_s__0__HSIOM_MASK)
    #define Tx8_MISO_S_HSIOM_POS       (Tx8_miso_s__0__HSIOM_SHIFT)
    #define Tx8_MISO_S_HSIOM_SEL_GPIO  (Tx8_miso_s__0__HSIOM_GPIO)
    #define Tx8_MISO_S_HSIOM_SEL_SPI   (Tx8_miso_s__0__HSIOM_SPI)
#endif /* (Tx8_SPI_SLAVE_MISO_PIN) */

#if (Tx8_SPI_MASTER_MISO_PIN)
    #define Tx8_MISO_M_HSIOM_REG   (*(reg32 *) Tx8_miso_m__0__HSIOM)
    #define Tx8_MISO_M_HSIOM_PTR   ( (reg32 *) Tx8_miso_m__0__HSIOM)
    
    #define Tx8_MISO_M_HSIOM_MASK      (Tx8_miso_m__0__HSIOM_MASK)
    #define Tx8_MISO_M_HSIOM_POS       (Tx8_miso_m__0__HSIOM_SHIFT)
    #define Tx8_MISO_M_HSIOM_SEL_GPIO  (Tx8_miso_m__0__HSIOM_GPIO)
    #define Tx8_MISO_M_HSIOM_SEL_SPI   (Tx8_miso_m__0__HSIOM_SPI)
#endif /* (Tx8_SPI_MASTER_MISO_PIN) */

#if (Tx8_SPI_MASTER_MOSI_PIN)
    #define Tx8_MOSI_M_HSIOM_REG   (*(reg32 *) Tx8_mosi_m__0__HSIOM)
    #define Tx8_MOSI_M_HSIOM_PTR   ( (reg32 *) Tx8_mosi_m__0__HSIOM)
    
    #define Tx8_MOSI_M_HSIOM_MASK      (Tx8_mosi_m__0__HSIOM_MASK)
    #define Tx8_MOSI_M_HSIOM_POS       (Tx8_mosi_m__0__HSIOM_SHIFT)
    #define Tx8_MOSI_M_HSIOM_SEL_GPIO  (Tx8_mosi_m__0__HSIOM_GPIO)
    #define Tx8_MOSI_M_HSIOM_SEL_SPI   (Tx8_mosi_m__0__HSIOM_SPI)
#endif /* (Tx8_SPI_MASTER_MOSI_PIN) */

#if (Tx8_SPI_MASTER_SCLK_PIN)
    #define Tx8_SCLK_M_HSIOM_REG   (*(reg32 *) Tx8_sclk_m__0__HSIOM)
    #define Tx8_SCLK_M_HSIOM_PTR   ( (reg32 *) Tx8_sclk_m__0__HSIOM)
    
    #define Tx8_SCLK_M_HSIOM_MASK      (Tx8_sclk_m__0__HSIOM_MASK)
    #define Tx8_SCLK_M_HSIOM_POS       (Tx8_sclk_m__0__HSIOM_SHIFT)
    #define Tx8_SCLK_M_HSIOM_SEL_GPIO  (Tx8_sclk_m__0__HSIOM_GPIO)
    #define Tx8_SCLK_M_HSIOM_SEL_SPI   (Tx8_sclk_m__0__HSIOM_SPI)
#endif /* (Tx8_SPI_MASTER_SCLK_PIN) */

#if (Tx8_SPI_MASTER_SS0_PIN)
    #define Tx8_SS0_M_HSIOM_REG    (*(reg32 *) Tx8_ss0_m__0__HSIOM)
    #define Tx8_SS0_M_HSIOM_PTR    ( (reg32 *) Tx8_ss0_m__0__HSIOM)
    
    #define Tx8_SS0_M_HSIOM_MASK       (Tx8_ss0_m__0__HSIOM_MASK)
    #define Tx8_SS0_M_HSIOM_POS        (Tx8_ss0_m__0__HSIOM_SHIFT)
    #define Tx8_SS0_M_HSIOM_SEL_GPIO   (Tx8_ss0_m__0__HSIOM_GPIO)
    #define Tx8_SS0_M_HSIOM_SEL_SPI    (Tx8_ss0_m__0__HSIOM_SPI)
#endif /* (Tx8_SPI_MASTER_SS0_PIN) */

#if (Tx8_SPI_MASTER_SS1_PIN)
    #define Tx8_SS1_M_HSIOM_REG    (*(reg32 *) Tx8_ss1_m__0__HSIOM)
    #define Tx8_SS1_M_HSIOM_PTR    ( (reg32 *) Tx8_ss1_m__0__HSIOM)
    
    #define Tx8_SS1_M_HSIOM_MASK       (Tx8_ss1_m__0__HSIOM_MASK)
    #define Tx8_SS1_M_HSIOM_POS        (Tx8_ss1_m__0__HSIOM_SHIFT)
    #define Tx8_SS1_M_HSIOM_SEL_GPIO   (Tx8_ss1_m__0__HSIOM_GPIO)
    #define Tx8_SS1_M_HSIOM_SEL_SPI    (Tx8_ss1_m__0__HSIOM_SPI)
#endif /* (Tx8_SPI_MASTER_SS1_PIN) */

#if (Tx8_SPI_MASTER_SS2_PIN)
    #define Tx8_SS2_M_HSIOM_REG    (*(reg32 *) Tx8_ss2_m__0__HSIOM)
    #define Tx8_SS2_M_HSIOM_PTR    ( (reg32 *) Tx8_ss2_m__0__HSIOM)
    
    #define Tx8_SS2_M_HSIOM_MASK       (Tx8_ss2_m__0__HSIOM_MASK)
    #define Tx8_SS2_M_HSIOM_POS        (Tx8_ss2_m__0__HSIOM_SHIFT)
    #define Tx8_SS2_M_HSIOM_SEL_GPIO   (Tx8_ss2_m__0__HSIOM_GPIO)
    #define Tx8_SS2_M_HSIOM_SEL_SPI    (Tx8_ss2_m__0__HSIOM_SPI)
#endif /* (Tx8_SPI_MASTER_SS2_PIN) */

#if (Tx8_SPI_MASTER_SS3_PIN)
    #define Tx8_SS3_M_HSIOM_REG    (*(reg32 *) Tx8_ss3_m__0__HSIOM)
    #define Tx8_SS3_M_HSIOM_PTR    ( (reg32 *) Tx8_ss3_m__0__HSIOM)
    
    #define Tx8_SS3_M_HSIOM_MASK      (Tx8_ss3_m__0__HSIOM_MASK)
    #define Tx8_SS3_M_HSIOM_POS       (Tx8_ss3_m__0__HSIOM_SHIFT)
    #define Tx8_SS3_M_HSIOM_SEL_GPIO  (Tx8_ss3_m__0__HSIOM_GPIO)
    #define Tx8_SS3_M_HSIOM_SEL_SPI   (Tx8_ss3_m__0__HSIOM_SPI)
#endif /* (Tx8_SPI_MASTER_SS3_PIN) */

#if (Tx8_UART_RX_PIN)
    #define Tx8_RX_HSIOM_REG   (*(reg32 *) Tx8_rx__0__HSIOM)
    #define Tx8_RX_HSIOM_PTR   ( (reg32 *) Tx8_rx__0__HSIOM)
    
    #define Tx8_RX_HSIOM_MASK      (Tx8_rx__0__HSIOM_MASK)
    #define Tx8_RX_HSIOM_POS       (Tx8_rx__0__HSIOM_SHIFT)
    #define Tx8_RX_HSIOM_SEL_GPIO  (Tx8_rx__0__HSIOM_GPIO)
    #define Tx8_RX_HSIOM_SEL_UART  (Tx8_rx__0__HSIOM_UART)
#endif /* (Tx8_UART_RX_PIN) */

#if (Tx8_UART_RX_WAKE_PIN)
    #define Tx8_RX_WAKE_HSIOM_REG   (*(reg32 *) Tx8_rx_wake__0__HSIOM)
    #define Tx8_RX_WAKE_HSIOM_PTR   ( (reg32 *) Tx8_rx_wake__0__HSIOM)
    
    #define Tx8_RX_WAKE_HSIOM_MASK      (Tx8_rx_wake__0__HSIOM_MASK)
    #define Tx8_RX_WAKE_HSIOM_POS       (Tx8_rx_wake__0__HSIOM_SHIFT)
    #define Tx8_RX_WAKE_HSIOM_SEL_GPIO  (Tx8_rx_wake__0__HSIOM_GPIO)
    #define Tx8_RX_WAKE_HSIOM_SEL_UART  (Tx8_rx_wake__0__HSIOM_UART)
#endif /* (Tx8_UART_WAKE_RX_PIN) */

#if (Tx8_UART_CTS_PIN)
    #define Tx8_CTS_HSIOM_REG   (*(reg32 *) Tx8_cts__0__HSIOM)
    #define Tx8_CTS_HSIOM_PTR   ( (reg32 *) Tx8_cts__0__HSIOM)
    
    #define Tx8_CTS_HSIOM_MASK      (Tx8_cts__0__HSIOM_MASK)
    #define Tx8_CTS_HSIOM_POS       (Tx8_cts__0__HSIOM_SHIFT)
    #define Tx8_CTS_HSIOM_SEL_GPIO  (Tx8_cts__0__HSIOM_GPIO)
    #define Tx8_CTS_HSIOM_SEL_UART  (Tx8_cts__0__HSIOM_UART)
#endif /* (Tx8_UART_CTS_PIN) */

#if (Tx8_UART_TX_PIN)
    #define Tx8_TX_HSIOM_REG   (*(reg32 *) Tx8_tx__0__HSIOM)
    #define Tx8_TX_HSIOM_PTR   ( (reg32 *) Tx8_tx__0__HSIOM)
    
    #define Tx8_TX_HSIOM_MASK      (Tx8_tx__0__HSIOM_MASK)
    #define Tx8_TX_HSIOM_POS       (Tx8_tx__0__HSIOM_SHIFT)
    #define Tx8_TX_HSIOM_SEL_GPIO  (Tx8_tx__0__HSIOM_GPIO)
    #define Tx8_TX_HSIOM_SEL_UART  (Tx8_tx__0__HSIOM_UART)
#endif /* (Tx8_UART_TX_PIN) */

#if (Tx8_UART_RX_TX_PIN)
    #define Tx8_RX_TX_HSIOM_REG   (*(reg32 *) Tx8_rx_tx__0__HSIOM)
    #define Tx8_RX_TX_HSIOM_PTR   ( (reg32 *) Tx8_rx_tx__0__HSIOM)
    
    #define Tx8_RX_TX_HSIOM_MASK      (Tx8_rx_tx__0__HSIOM_MASK)
    #define Tx8_RX_TX_HSIOM_POS       (Tx8_rx_tx__0__HSIOM_SHIFT)
    #define Tx8_RX_TX_HSIOM_SEL_GPIO  (Tx8_rx_tx__0__HSIOM_GPIO)
    #define Tx8_RX_TX_HSIOM_SEL_UART  (Tx8_rx_tx__0__HSIOM_UART)
#endif /* (Tx8_UART_RX_TX_PIN) */

#if (Tx8_UART_RTS_PIN)
    #define Tx8_RTS_HSIOM_REG      (*(reg32 *) Tx8_rts__0__HSIOM)
    #define Tx8_RTS_HSIOM_PTR      ( (reg32 *) Tx8_rts__0__HSIOM)
    
    #define Tx8_RTS_HSIOM_MASK     (Tx8_rts__0__HSIOM_MASK)
    #define Tx8_RTS_HSIOM_POS      (Tx8_rts__0__HSIOM_SHIFT)    
    #define Tx8_RTS_HSIOM_SEL_GPIO (Tx8_rts__0__HSIOM_GPIO)
    #define Tx8_RTS_HSIOM_SEL_UART (Tx8_rts__0__HSIOM_UART)    
#endif /* (Tx8_UART_RTS_PIN) */


/***************************************
*        Registers Constants
***************************************/

/* HSIOM switch values. */ 
#define Tx8_HSIOM_DEF_SEL      (0x00u)
#define Tx8_HSIOM_GPIO_SEL     (0x00u)
/* The HSIOM values provided below are valid only for Tx8_CY_SCBIP_V0 
* and Tx8_CY_SCBIP_V1. It is not recommended to use them for 
* Tx8_CY_SCBIP_V2. Use pin name specific HSIOM constants provided 
* above instead for any SCB IP block version.
*/
#define Tx8_HSIOM_UART_SEL     (0x09u)
#define Tx8_HSIOM_I2C_SEL      (0x0Eu)
#define Tx8_HSIOM_SPI_SEL      (0x0Fu)

/* Pins settings index. */
#define Tx8_RX_WAKE_SCL_MOSI_PIN_INDEX   (0u)
#define Tx8_RX_SCL_MOSI_PIN_INDEX       (0u)
#define Tx8_TX_SDA_MISO_PIN_INDEX       (1u)
#define Tx8_SCLK_PIN_INDEX       (2u)
#define Tx8_SS0_PIN_INDEX       (3u)
#define Tx8_SS1_PIN_INDEX                  (4u)
#define Tx8_SS2_PIN_INDEX                  (5u)
#define Tx8_SS3_PIN_INDEX                  (6u)

/* Pins settings mask. */
#define Tx8_RX_WAKE_SCL_MOSI_PIN_MASK ((uint32) 0x01u << Tx8_RX_WAKE_SCL_MOSI_PIN_INDEX)
#define Tx8_RX_SCL_MOSI_PIN_MASK     ((uint32) 0x01u << Tx8_RX_SCL_MOSI_PIN_INDEX)
#define Tx8_TX_SDA_MISO_PIN_MASK     ((uint32) 0x01u << Tx8_TX_SDA_MISO_PIN_INDEX)
#define Tx8_SCLK_PIN_MASK     ((uint32) 0x01u << Tx8_SCLK_PIN_INDEX)
#define Tx8_SS0_PIN_MASK     ((uint32) 0x01u << Tx8_SS0_PIN_INDEX)
#define Tx8_SS1_PIN_MASK                ((uint32) 0x01u << Tx8_SS1_PIN_INDEX)
#define Tx8_SS2_PIN_MASK                ((uint32) 0x01u << Tx8_SS2_PIN_INDEX)
#define Tx8_SS3_PIN_MASK                ((uint32) 0x01u << Tx8_SS3_PIN_INDEX)

/* Pin interrupt constants. */
#define Tx8_INTCFG_TYPE_MASK           (0x03u)
#define Tx8_INTCFG_TYPE_FALLING_EDGE   (0x02u)

/* Pin Drive Mode constants. */
#define Tx8_PIN_DM_ALG_HIZ  (0u)
#define Tx8_PIN_DM_DIG_HIZ  (1u)
#define Tx8_PIN_DM_OD_LO    (4u)
#define Tx8_PIN_DM_STRONG   (6u)


/***************************************
*          Macro Definitions
***************************************/

/* Return drive mode of the pin */
#define Tx8_DM_MASK    (0x7u)
#define Tx8_DM_SIZE    (3u)
#define Tx8_GET_P4_PIN_DM(reg, pos) \
    ( ((reg) & (uint32) ((uint32) Tx8_DM_MASK << (Tx8_DM_SIZE * (pos)))) >> \
                                                              (Tx8_DM_SIZE * (pos)) )

#if (Tx8_TX_SDA_MISO_PIN)
    #define Tx8_CHECK_TX_SDA_MISO_PIN_USED \
                (Tx8_PIN_DM_ALG_HIZ != \
                    Tx8_GET_P4_PIN_DM(Tx8_uart_tx_i2c_sda_spi_miso_PC, \
                                                   Tx8_uart_tx_i2c_sda_spi_miso_SHIFT))
#endif /* (Tx8_TX_SDA_MISO_PIN) */

#if (Tx8_SS0_PIN)
    #define Tx8_CHECK_SS0_PIN_USED \
                (Tx8_PIN_DM_ALG_HIZ != \
                    Tx8_GET_P4_PIN_DM(Tx8_spi_ss0_PC, \
                                                   Tx8_spi_ss0_SHIFT))
#endif /* (Tx8_SS0_PIN) */

/* Set bits-mask in register */
#define Tx8_SET_REGISTER_BITS(reg, mask, pos, mode) \
                    do                                           \
                    {                                            \
                        (reg) = (((reg) & ((uint32) ~(uint32) (mask))) | ((uint32) ((uint32) (mode) << (pos)))); \
                    }while(0)

/* Set bit in the register */
#define Tx8_SET_REGISTER_BIT(reg, mask, val) \
                    ((val) ? ((reg) |= (mask)) : ((reg) &= ((uint32) ~((uint32) (mask)))))

#define Tx8_SET_HSIOM_SEL(reg, mask, pos, sel) Tx8_SET_REGISTER_BITS(reg, mask, pos, sel)
#define Tx8_SET_INCFG_TYPE(reg, mask, pos, intType) \
                                                        Tx8_SET_REGISTER_BITS(reg, mask, pos, intType)
#define Tx8_SET_INP_DIS(reg, mask, val) Tx8_SET_REGISTER_BIT(reg, mask, val)

/* Tx8_SET_I2C_SCL_DR(val) - Sets I2C SCL DR register.
*  Tx8_SET_I2C_SCL_HSIOM_SEL(sel) - Sets I2C SCL HSIOM settings.
*/
/* SCB I2C: scl signal */
#if (Tx8_CY_SCBIP_V0)
#if (Tx8_I2C_PINS)
    #define Tx8_SET_I2C_SCL_DR(val) Tx8_scl_Write(val)

    #define Tx8_SET_I2C_SCL_HSIOM_SEL(sel) \
                          Tx8_SET_HSIOM_SEL(Tx8_SCL_HSIOM_REG,  \
                                                         Tx8_SCL_HSIOM_MASK, \
                                                         Tx8_SCL_HSIOM_POS,  \
                                                         (sel))
    #define Tx8_WAIT_SCL_SET_HIGH  (0u == Tx8_scl_Read())

/* Unconfigured SCB: scl signal */
#elif (Tx8_RX_WAKE_SCL_MOSI_PIN)
    #define Tx8_SET_I2C_SCL_DR(val) \
                            Tx8_uart_rx_wake_i2c_scl_spi_mosi_Write(val)

    #define Tx8_SET_I2C_SCL_HSIOM_SEL(sel) \
                    Tx8_SET_HSIOM_SEL(Tx8_RX_WAKE_SCL_MOSI_HSIOM_REG,  \
                                                   Tx8_RX_WAKE_SCL_MOSI_HSIOM_MASK, \
                                                   Tx8_RX_WAKE_SCL_MOSI_HSIOM_POS,  \
                                                   (sel))

    #define Tx8_WAIT_SCL_SET_HIGH  (0u == Tx8_uart_rx_wake_i2c_scl_spi_mosi_Read())

#elif (Tx8_RX_SCL_MOSI_PIN)
    #define Tx8_SET_I2C_SCL_DR(val) \
                            Tx8_uart_rx_i2c_scl_spi_mosi_Write(val)


    #define Tx8_SET_I2C_SCL_HSIOM_SEL(sel) \
                            Tx8_SET_HSIOM_SEL(Tx8_RX_SCL_MOSI_HSIOM_REG,  \
                                                           Tx8_RX_SCL_MOSI_HSIOM_MASK, \
                                                           Tx8_RX_SCL_MOSI_HSIOM_POS,  \
                                                           (sel))

    #define Tx8_WAIT_SCL_SET_HIGH  (0u == Tx8_uart_rx_i2c_scl_spi_mosi_Read())

#else
    #define Tx8_SET_I2C_SCL_DR(val)        do{ /* Does nothing */ }while(0)
    #define Tx8_SET_I2C_SCL_HSIOM_SEL(sel) do{ /* Does nothing */ }while(0)

    #define Tx8_WAIT_SCL_SET_HIGH  (0u)
#endif /* (Tx8_I2C_PINS) */

/* SCB I2C: sda signal */
#if (Tx8_I2C_PINS)
    #define Tx8_WAIT_SDA_SET_HIGH  (0u == Tx8_sda_Read())
/* Unconfigured SCB: sda signal */
#elif (Tx8_TX_SDA_MISO_PIN)
    #define Tx8_WAIT_SDA_SET_HIGH  (0u == Tx8_uart_tx_i2c_sda_spi_miso_Read())
#else
    #define Tx8_WAIT_SDA_SET_HIGH  (0u)
#endif /* (Tx8_MOSI_SCL_RX_PIN) */
#endif /* (Tx8_CY_SCBIP_V0) */

/* Clear UART wakeup source */
#if (Tx8_RX_SCL_MOSI_PIN)
    #define Tx8_CLEAR_UART_RX_WAKE_INTR        do{ /* Does nothing */ }while(0)
    
#elif (Tx8_RX_WAKE_SCL_MOSI_PIN)
    #define Tx8_CLEAR_UART_RX_WAKE_INTR \
            do{                                      \
                (void) Tx8_uart_rx_wake_i2c_scl_spi_mosi_ClearInterrupt(); \
            }while(0)

#elif(Tx8_UART_RX_WAKE_PIN)
    #define Tx8_CLEAR_UART_RX_WAKE_INTR \
            do{                                      \
                (void) Tx8_rx_wake_ClearInterrupt(); \
            }while(0)
#else
#endif /* (Tx8_RX_SCL_MOSI_PIN) */


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

/* Unconfigured pins */
#define Tx8_REMOVE_MOSI_SCL_RX_WAKE_PIN    Tx8_REMOVE_RX_WAKE_SCL_MOSI_PIN
#define Tx8_REMOVE_MOSI_SCL_RX_PIN         Tx8_REMOVE_RX_SCL_MOSI_PIN
#define Tx8_REMOVE_MISO_SDA_TX_PIN         Tx8_REMOVE_TX_SDA_MISO_PIN
#ifndef Tx8_REMOVE_SCLK_PIN
#define Tx8_REMOVE_SCLK_PIN                Tx8_REMOVE_SCLK_PIN
#endif /* Tx8_REMOVE_SCLK_PIN */
#ifndef Tx8_REMOVE_SS0_PIN
#define Tx8_REMOVE_SS0_PIN                 Tx8_REMOVE_SS0_PIN
#endif /* Tx8_REMOVE_SS0_PIN */

/* Unconfigured pins */
#define Tx8_MOSI_SCL_RX_WAKE_PIN   Tx8_RX_WAKE_SCL_MOSI_PIN
#define Tx8_MOSI_SCL_RX_PIN        Tx8_RX_SCL_MOSI_PIN
#define Tx8_MISO_SDA_TX_PIN        Tx8_TX_SDA_MISO_PIN
#ifndef Tx8_SCLK_PIN
#define Tx8_SCLK_PIN               Tx8_SCLK_PIN
#endif /* Tx8_SCLK_PIN */
#ifndef Tx8_SS0_PIN
#define Tx8_SS0_PIN                Tx8_SS0_PIN
#endif /* Tx8_SS0_PIN */

#if (Tx8_MOSI_SCL_RX_WAKE_PIN)
    #define Tx8_MOSI_SCL_RX_WAKE_HSIOM_REG     Tx8_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define Tx8_MOSI_SCL_RX_WAKE_HSIOM_PTR     Tx8_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define Tx8_MOSI_SCL_RX_WAKE_HSIOM_MASK    Tx8_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define Tx8_MOSI_SCL_RX_WAKE_HSIOM_POS     Tx8_RX_WAKE_SCL_MOSI_HSIOM_REG

    #define Tx8_MOSI_SCL_RX_WAKE_INTCFG_REG    Tx8_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define Tx8_MOSI_SCL_RX_WAKE_INTCFG_PTR    Tx8_RX_WAKE_SCL_MOSI_HSIOM_REG

    #define Tx8_MOSI_SCL_RX_WAKE_INTCFG_TYPE_POS   Tx8_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define Tx8_MOSI_SCL_RX_WAKE_INTCFG_TYPE_MASK  Tx8_RX_WAKE_SCL_MOSI_HSIOM_REG
#endif /* (Tx8_RX_WAKE_SCL_MOSI_PIN) */

#if (Tx8_MOSI_SCL_RX_PIN)
    #define Tx8_MOSI_SCL_RX_HSIOM_REG      Tx8_RX_SCL_MOSI_HSIOM_REG
    #define Tx8_MOSI_SCL_RX_HSIOM_PTR      Tx8_RX_SCL_MOSI_HSIOM_PTR
    #define Tx8_MOSI_SCL_RX_HSIOM_MASK     Tx8_RX_SCL_MOSI_HSIOM_MASK
    #define Tx8_MOSI_SCL_RX_HSIOM_POS      Tx8_RX_SCL_MOSI_HSIOM_POS
#endif /* (Tx8_MOSI_SCL_RX_PIN) */

#if (Tx8_MISO_SDA_TX_PIN)
    #define Tx8_MISO_SDA_TX_HSIOM_REG      Tx8_TX_SDA_MISO_HSIOM_REG
    #define Tx8_MISO_SDA_TX_HSIOM_PTR      Tx8_TX_SDA_MISO_HSIOM_REG
    #define Tx8_MISO_SDA_TX_HSIOM_MASK     Tx8_TX_SDA_MISO_HSIOM_REG
    #define Tx8_MISO_SDA_TX_HSIOM_POS      Tx8_TX_SDA_MISO_HSIOM_REG
#endif /* (Tx8_MISO_SDA_TX_PIN_PIN) */

#if (Tx8_SCLK_PIN)
    #ifndef Tx8_SCLK_HSIOM_REG
    #define Tx8_SCLK_HSIOM_REG     Tx8_SCLK_HSIOM_REG
    #define Tx8_SCLK_HSIOM_PTR     Tx8_SCLK_HSIOM_PTR
    #define Tx8_SCLK_HSIOM_MASK    Tx8_SCLK_HSIOM_MASK
    #define Tx8_SCLK_HSIOM_POS     Tx8_SCLK_HSIOM_POS
    #endif /* Tx8_SCLK_HSIOM_REG */
#endif /* (Tx8_SCLK_PIN) */

#if (Tx8_SS0_PIN)
    #ifndef Tx8_SS0_HSIOM_REG
    #define Tx8_SS0_HSIOM_REG      Tx8_SS0_HSIOM_REG
    #define Tx8_SS0_HSIOM_PTR      Tx8_SS0_HSIOM_PTR
    #define Tx8_SS0_HSIOM_MASK     Tx8_SS0_HSIOM_MASK
    #define Tx8_SS0_HSIOM_POS      Tx8_SS0_HSIOM_POS
    #endif /* Tx8_SS0_HSIOM_REG */
#endif /* (Tx8_SS0_PIN) */

#define Tx8_MOSI_SCL_RX_WAKE_PIN_INDEX Tx8_RX_WAKE_SCL_MOSI_PIN_INDEX
#define Tx8_MOSI_SCL_RX_PIN_INDEX      Tx8_RX_SCL_MOSI_PIN_INDEX
#define Tx8_MISO_SDA_TX_PIN_INDEX      Tx8_TX_SDA_MISO_PIN_INDEX
#ifndef Tx8_SCLK_PIN_INDEX
#define Tx8_SCLK_PIN_INDEX             Tx8_SCLK_PIN_INDEX
#endif /* Tx8_SCLK_PIN_INDEX */
#ifndef Tx8_SS0_PIN_INDEX
#define Tx8_SS0_PIN_INDEX              Tx8_SS0_PIN_INDEX
#endif /* Tx8_SS0_PIN_INDEX */

#define Tx8_MOSI_SCL_RX_WAKE_PIN_MASK Tx8_RX_WAKE_SCL_MOSI_PIN_MASK
#define Tx8_MOSI_SCL_RX_PIN_MASK      Tx8_RX_SCL_MOSI_PIN_MASK
#define Tx8_MISO_SDA_TX_PIN_MASK      Tx8_TX_SDA_MISO_PIN_MASK
#ifndef Tx8_SCLK_PIN_MASK
#define Tx8_SCLK_PIN_MASK             Tx8_SCLK_PIN_MASK
#endif /* Tx8_SCLK_PIN_MASK */
#ifndef Tx8_SS0_PIN_MASK
#define Tx8_SS0_PIN_MASK              Tx8_SS0_PIN_MASK
#endif /* Tx8_SS0_PIN_MASK */

#endif /* (CY_SCB_PINS_Tx8_H) */


/* [] END OF FILE */
