/***************************************************************************//**
* \file Tx8_SPI_UART_PVT.h
* \version 4.0
*
* \brief
*  This private file provides constants and parameter values for the
*  SCB Component in SPI and UART modes.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2017, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_SPI_UART_PVT_Tx8_H)
#define CY_SCB_SPI_UART_PVT_Tx8_H

#include "Tx8_SPI_UART.h"


/***************************************
*     Internal Global Vars
***************************************/

#if (Tx8_INTERNAL_RX_SW_BUFFER_CONST)
    extern volatile uint32  Tx8_rxBufferHead;
    extern volatile uint32  Tx8_rxBufferTail;
    
    /**
    * \addtogroup group_globals
    * @{
    */
    
    /** Sets when internal software receive buffer overflow
     *  was occurred.
    */  
    extern volatile uint8   Tx8_rxBufferOverflow;
    /** @} globals */
#endif /* (Tx8_INTERNAL_RX_SW_BUFFER_CONST) */

#if (Tx8_INTERNAL_TX_SW_BUFFER_CONST)
    extern volatile uint32  Tx8_txBufferHead;
    extern volatile uint32  Tx8_txBufferTail;
#endif /* (Tx8_INTERNAL_TX_SW_BUFFER_CONST) */

#if (Tx8_INTERNAL_RX_SW_BUFFER)
    extern volatile uint8 Tx8_rxBufferInternal[Tx8_INTERNAL_RX_BUFFER_SIZE];
#endif /* (Tx8_INTERNAL_RX_SW_BUFFER) */

#if (Tx8_INTERNAL_TX_SW_BUFFER)
    extern volatile uint8 Tx8_txBufferInternal[Tx8_TX_BUFFER_SIZE];
#endif /* (Tx8_INTERNAL_TX_SW_BUFFER) */


/***************************************
*     Private Function Prototypes
***************************************/

void Tx8_SpiPostEnable(void);
void Tx8_SpiStop(void);

#if (Tx8_SCB_MODE_SPI_CONST_CFG)
    void Tx8_SpiInit(void);
#endif /* (Tx8_SCB_MODE_SPI_CONST_CFG) */

#if (Tx8_SPI_WAKE_ENABLE_CONST)
    void Tx8_SpiSaveConfig(void);
    void Tx8_SpiRestoreConfig(void);
#endif /* (Tx8_SPI_WAKE_ENABLE_CONST) */

void Tx8_UartPostEnable(void);
void Tx8_UartStop(void);

#if (Tx8_SCB_MODE_UART_CONST_CFG)
    void Tx8_UartInit(void);
#endif /* (Tx8_SCB_MODE_UART_CONST_CFG) */

#if (Tx8_UART_WAKE_ENABLE_CONST)
    void Tx8_UartSaveConfig(void);
    void Tx8_UartRestoreConfig(void);
#endif /* (Tx8_UART_WAKE_ENABLE_CONST) */


/***************************************
*         UART API Constants
***************************************/

/* UART RX and TX position to be used in Tx8_SetPins() */
#define Tx8_UART_RX_PIN_ENABLE    (Tx8_UART_RX)
#define Tx8_UART_TX_PIN_ENABLE    (Tx8_UART_TX)

/* UART RTS and CTS position to be used in  Tx8_SetPins() */
#define Tx8_UART_RTS_PIN_ENABLE    (0x10u)
#define Tx8_UART_CTS_PIN_ENABLE    (0x20u)


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

/* Interrupt processing */
#define Tx8_SpiUartEnableIntRx(intSourceMask)  Tx8_SetRxInterruptMode(intSourceMask)
#define Tx8_SpiUartEnableIntTx(intSourceMask)  Tx8_SetTxInterruptMode(intSourceMask)
uint32  Tx8_SpiUartDisableIntRx(void);
uint32  Tx8_SpiUartDisableIntTx(void);


#endif /* (CY_SCB_SPI_UART_PVT_Tx8_H) */


/* [] END OF FILE */
