/***************************************************************************//**
* \file Tx8.c
* \version 4.0
*
* \brief
*  This file provides the source code to the API for the SCB Component.
*
* Note:
*
*******************************************************************************
* \copyright
* Copyright 2013-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Tx8_PVT.h"

#if (Tx8_SCB_MODE_I2C_INC)
    #include "Tx8_I2C_PVT.h"
#endif /* (Tx8_SCB_MODE_I2C_INC) */

#if (Tx8_SCB_MODE_EZI2C_INC)
    #include "Tx8_EZI2C_PVT.h"
#endif /* (Tx8_SCB_MODE_EZI2C_INC) */

#if (Tx8_SCB_MODE_SPI_INC || Tx8_SCB_MODE_UART_INC)
    #include "Tx8_SPI_UART_PVT.h"
#endif /* (Tx8_SCB_MODE_SPI_INC || Tx8_SCB_MODE_UART_INC) */


/***************************************
*    Run Time Configuration Vars
***************************************/

/* Stores internal component configuration for Unconfigured mode */
#if (Tx8_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common configuration variables */
    uint8 Tx8_scbMode = Tx8_SCB_MODE_UNCONFIG;
    uint8 Tx8_scbEnableWake;
    uint8 Tx8_scbEnableIntr;

    /* I2C configuration variables */
    uint8 Tx8_mode;
    uint8 Tx8_acceptAddr;

    /* SPI/UART configuration variables */
    volatile uint8 * Tx8_rxBuffer;
    uint8  Tx8_rxDataBits;
    uint32 Tx8_rxBufferSize;

    volatile uint8 * Tx8_txBuffer;
    uint8  Tx8_txDataBits;
    uint32 Tx8_txBufferSize;

    /* EZI2C configuration variables */
    uint8 Tx8_numberOfAddr;
    uint8 Tx8_subAddrSize;
#endif /* (Tx8_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Common SCB Vars
***************************************/
/**
* \addtogroup group_general
* \{
*/

/** Tx8_initVar indicates whether the Tx8 
*  component has been initialized. The variable is initialized to 0 
*  and set to 1 the first time SCB_Start() is called. This allows 
*  the component to restart without reinitialization after the first 
*  call to the Tx8_Start() routine.
*
*  If re-initialization of the component is required, then the 
*  Tx8_Init() function can be called before the 
*  Tx8_Start() or Tx8_Enable() function.
*/
uint8 Tx8_initVar = 0u;


#if (! (Tx8_SCB_MODE_I2C_CONST_CFG || \
        Tx8_SCB_MODE_EZI2C_CONST_CFG))
    /** This global variable stores TX interrupt sources after 
    * Tx8_Stop() is called. Only these TX interrupt sources 
    * will be restored on a subsequent Tx8_Enable() call.
    */
    uint16 Tx8_IntrTxMask = 0u;
#endif /* (! (Tx8_SCB_MODE_I2C_CONST_CFG || \
              Tx8_SCB_MODE_EZI2C_CONST_CFG)) */
/** \} globals */

#if (Tx8_SCB_IRQ_INTERNAL)
#if !defined (CY_REMOVE_Tx8_CUSTOM_INTR_HANDLER)
    void (*Tx8_customIntrHandler)(void) = NULL;
#endif /* !defined (CY_REMOVE_Tx8_CUSTOM_INTR_HANDLER) */
#endif /* (Tx8_SCB_IRQ_INTERNAL) */


/***************************************
*    Private Function Prototypes
***************************************/

static void Tx8_ScbEnableIntr(void);
static void Tx8_ScbModeStop(void);
static void Tx8_ScbModePostEnable(void);


/*******************************************************************************
* Function Name: Tx8_Init
****************************************************************************//**
*
*  Initializes the Tx8 component to operate in one of the selected
*  configurations: I2C, SPI, UART or EZI2C.
*  When the configuration is set to "Unconfigured SCB", this function does
*  not do any initialization. Use mode-specific initialization APIs instead:
*  Tx8_I2CInit, Tx8_SpiInit, 
*  Tx8_UartInit or Tx8_EzI2CInit.
*
*******************************************************************************/
void Tx8_Init(void)
{
#if (Tx8_SCB_MODE_UNCONFIG_CONST_CFG)
    if (Tx8_SCB_MODE_UNCONFIG_RUNTM_CFG)
    {
        Tx8_initVar = 0u;
    }
    else
    {
        /* Initialization was done before this function call */
    }

#elif (Tx8_SCB_MODE_I2C_CONST_CFG)
    Tx8_I2CInit();

#elif (Tx8_SCB_MODE_SPI_CONST_CFG)
    Tx8_SpiInit();

#elif (Tx8_SCB_MODE_UART_CONST_CFG)
    Tx8_UartInit();

#elif (Tx8_SCB_MODE_EZI2C_CONST_CFG)
    Tx8_EzI2CInit();

#endif /* (Tx8_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: Tx8_Enable
****************************************************************************//**
*
*  Enables Tx8 component operation: activates the hardware and 
*  internal interrupt. It also restores TX interrupt sources disabled after the 
*  Tx8_Stop() function was called (note that level-triggered TX 
*  interrupt sources remain disabled to not cause code lock-up).
*  For I2C and EZI2C modes the interrupt is internal and mandatory for 
*  operation. For SPI and UART modes the interrupt can be configured as none, 
*  internal or external.
*  The Tx8 configuration should be not changed when the component
*  is enabled. Any configuration changes should be made after disabling the 
*  component.
*  When configuration is set to “Unconfigured Tx8”, the component 
*  must first be initialized to operate in one of the following configurations: 
*  I2C, SPI, UART or EZ I2C, using the mode-specific initialization API. 
*  Otherwise this function does not enable the component.
*
*******************************************************************************/
void Tx8_Enable(void)
{
#if (Tx8_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Enable SCB block, only if it is already configured */
    if (!Tx8_SCB_MODE_UNCONFIG_RUNTM_CFG)
    {
        Tx8_CTRL_REG |= Tx8_CTRL_ENABLED;

        Tx8_ScbEnableIntr();

        /* Call PostEnable function specific to current operation mode */
        Tx8_ScbModePostEnable();
    }
#else
    Tx8_CTRL_REG |= Tx8_CTRL_ENABLED;

    Tx8_ScbEnableIntr();

    /* Call PostEnable function specific to current operation mode */
    Tx8_ScbModePostEnable();
#endif /* (Tx8_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: Tx8_Start
****************************************************************************//**
*
*  Invokes Tx8_Init() and Tx8_Enable().
*  After this function call, the component is enabled and ready for operation.
*  When configuration is set to "Unconfigured SCB", the component must first be
*  initialized to operate in one of the following configurations: I2C, SPI, UART
*  or EZI2C. Otherwise this function does not enable the component.
*
* \globalvars
*  Tx8_initVar - used to check initial configuration, modified
*  on first function call.
*
*******************************************************************************/
void Tx8_Start(void)
{
    if (0u == Tx8_initVar)
    {
        Tx8_Init();
        Tx8_initVar = 1u; /* Component was initialized */
    }

    Tx8_Enable();
}


/*******************************************************************************
* Function Name: Tx8_Stop
****************************************************************************//**
*
*  Disables the Tx8 component: disable the hardware and internal 
*  interrupt. It also disables all TX interrupt sources so as not to cause an 
*  unexpected interrupt trigger because after the component is enabled, the 
*  TX FIFO is empty.
*  Refer to the function Tx8_Enable() for the interrupt 
*  configuration details.
*  This function disables the SCB component without checking to see if 
*  communication is in progress. Before calling this function it may be 
*  necessary to check the status of communication to make sure communication 
*  is complete. If this is not done then communication could be stopped mid 
*  byte and corrupted data could result.
*
*******************************************************************************/
void Tx8_Stop(void)
{
#if (Tx8_SCB_IRQ_INTERNAL)
    Tx8_DisableInt();
#endif /* (Tx8_SCB_IRQ_INTERNAL) */

    /* Call Stop function specific to current operation mode */
    Tx8_ScbModeStop();

    /* Disable SCB IP */
    Tx8_CTRL_REG &= (uint32) ~Tx8_CTRL_ENABLED;

    /* Disable all TX interrupt sources so as not to cause an unexpected
    * interrupt trigger after the component will be enabled because the 
    * TX FIFO is empty.
    * For SCB IP v0, it is critical as it does not mask-out interrupt
    * sources when it is disabled. This can cause a code lock-up in the
    * interrupt handler because TX FIFO cannot be loaded after the block
    * is disabled.
    */
    Tx8_SetTxInterruptMode(Tx8_NO_INTR_SOURCES);

#if (Tx8_SCB_IRQ_INTERNAL)
    Tx8_ClearPendingInt();
#endif /* (Tx8_SCB_IRQ_INTERNAL) */
}


/*******************************************************************************
* Function Name: Tx8_SetRxFifoLevel
****************************************************************************//**
*
*  Sets level in the RX FIFO to generate a RX level interrupt.
*  When the RX FIFO has more entries than the RX FIFO level an RX level
*  interrupt request is generated.
*
*  \param level: Level in the RX FIFO to generate RX level interrupt.
*   The range of valid level values is between 0 and RX FIFO depth - 1.
*
*******************************************************************************/
void Tx8_SetRxFifoLevel(uint32 level)
{
    uint32 rxFifoCtrl;

    rxFifoCtrl = Tx8_RX_FIFO_CTRL_REG;

    rxFifoCtrl &= ((uint32) ~Tx8_RX_FIFO_CTRL_TRIGGER_LEVEL_MASK); /* Clear level mask bits */
    rxFifoCtrl |= ((uint32) (Tx8_RX_FIFO_CTRL_TRIGGER_LEVEL_MASK & level));

    Tx8_RX_FIFO_CTRL_REG = rxFifoCtrl;
}


/*******************************************************************************
* Function Name: Tx8_SetTxFifoLevel
****************************************************************************//**
*
*  Sets level in the TX FIFO to generate a TX level interrupt.
*  When the TX FIFO has less entries than the TX FIFO level an TX level
*  interrupt request is generated.
*
*  \param level: Level in the TX FIFO to generate TX level interrupt.
*   The range of valid level values is between 0 and TX FIFO depth - 1.
*
*******************************************************************************/
void Tx8_SetTxFifoLevel(uint32 level)
{
    uint32 txFifoCtrl;

    txFifoCtrl = Tx8_TX_FIFO_CTRL_REG;

    txFifoCtrl &= ((uint32) ~Tx8_TX_FIFO_CTRL_TRIGGER_LEVEL_MASK); /* Clear level mask bits */
    txFifoCtrl |= ((uint32) (Tx8_TX_FIFO_CTRL_TRIGGER_LEVEL_MASK & level));

    Tx8_TX_FIFO_CTRL_REG = txFifoCtrl;
}


#if (Tx8_SCB_IRQ_INTERNAL)
    /*******************************************************************************
    * Function Name: Tx8_SetCustomInterruptHandler
    ****************************************************************************//**
    *
    *  Registers a function to be called by the internal interrupt handler.
    *  First the function that is registered is called, then the internal interrupt
    *  handler performs any operation such as software buffer management functions
    *  before the interrupt returns.  It is the user's responsibility not to break
    *  the software buffer operations. Only one custom handler is supported, which
    *  is the function provided by the most recent call.
    *  At the initialization time no custom handler is registered.
    *
    *  \param func: Pointer to the function to register.
    *        The value NULL indicates to remove the current custom interrupt
    *        handler.
    *
    *******************************************************************************/
    void Tx8_SetCustomInterruptHandler(void (*func)(void))
    {
    #if !defined (CY_REMOVE_Tx8_CUSTOM_INTR_HANDLER)
        Tx8_customIntrHandler = func; /* Register interrupt handler */
    #else
        if (NULL != func)
        {
            /* Suppress compiler warning */
        }
    #endif /* !defined (CY_REMOVE_Tx8_CUSTOM_INTR_HANDLER) */
    }
#endif /* (Tx8_SCB_IRQ_INTERNAL) */


/*******************************************************************************
* Function Name: Tx8_ScbModeEnableIntr
****************************************************************************//**
*
*  Enables an interrupt for a specific mode.
*
*******************************************************************************/
static void Tx8_ScbEnableIntr(void)
{
#if (Tx8_SCB_IRQ_INTERNAL)
    /* Enable interrupt in NVIC */
    #if (Tx8_SCB_MODE_UNCONFIG_CONST_CFG)
        if (0u != Tx8_scbEnableIntr)
        {
            Tx8_EnableInt();
        }

    #else
        Tx8_EnableInt();

    #endif /* (Tx8_SCB_MODE_UNCONFIG_CONST_CFG) */
#endif /* (Tx8_SCB_IRQ_INTERNAL) */
}


/*******************************************************************************
* Function Name: Tx8_ScbModePostEnable
****************************************************************************//**
*
*  Calls the PostEnable function for a specific operation mode.
*
*******************************************************************************/
static void Tx8_ScbModePostEnable(void)
{
#if (Tx8_SCB_MODE_UNCONFIG_CONST_CFG)
#if (!Tx8_CY_SCBIP_V1)
    if (Tx8_SCB_MODE_SPI_RUNTM_CFG)
    {
        Tx8_SpiPostEnable();
    }
    else if (Tx8_SCB_MODE_UART_RUNTM_CFG)
    {
        Tx8_UartPostEnable();
    }
    else
    {
        /* Unknown mode: do nothing */
    }
#endif /* (!Tx8_CY_SCBIP_V1) */

#elif (Tx8_SCB_MODE_SPI_CONST_CFG)
    Tx8_SpiPostEnable();

#elif (Tx8_SCB_MODE_UART_CONST_CFG)
    Tx8_UartPostEnable();

#else
    /* Unknown mode: do nothing */
#endif /* (Tx8_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: Tx8_ScbModeStop
****************************************************************************//**
*
*  Calls the Stop function for a specific operation mode.
*
*******************************************************************************/
static void Tx8_ScbModeStop(void)
{
#if (Tx8_SCB_MODE_UNCONFIG_CONST_CFG)
    if (Tx8_SCB_MODE_I2C_RUNTM_CFG)
    {
        Tx8_I2CStop();
    }
    else if (Tx8_SCB_MODE_EZI2C_RUNTM_CFG)
    {
        Tx8_EzI2CStop();
    }
#if (!Tx8_CY_SCBIP_V1)
    else if (Tx8_SCB_MODE_SPI_RUNTM_CFG)
    {
        Tx8_SpiStop();
    }
    else if (Tx8_SCB_MODE_UART_RUNTM_CFG)
    {
        Tx8_UartStop();
    }
#endif /* (!Tx8_CY_SCBIP_V1) */
    else
    {
        /* Unknown mode: do nothing */
    }
#elif (Tx8_SCB_MODE_I2C_CONST_CFG)
    Tx8_I2CStop();

#elif (Tx8_SCB_MODE_EZI2C_CONST_CFG)
    Tx8_EzI2CStop();

#elif (Tx8_SCB_MODE_SPI_CONST_CFG)
    Tx8_SpiStop();

#elif (Tx8_SCB_MODE_UART_CONST_CFG)
    Tx8_UartStop();

#else
    /* Unknown mode: do nothing */
#endif /* (Tx8_SCB_MODE_UNCONFIG_CONST_CFG) */
}


#if (Tx8_SCB_MODE_UNCONFIG_CONST_CFG)
    /*******************************************************************************
    * Function Name: Tx8_SetPins
    ****************************************************************************//**
    *
    *  Sets the pins settings accordingly to the selected operation mode.
    *  Only available in the Unconfigured operation mode. The mode specific
    *  initialization function calls it.
    *  Pins configuration is set by PSoC Creator when a specific mode of operation
    *  is selected in design time.
    *
    *  \param mode:      Mode of SCB operation.
    *  \param subMode:   Sub-mode of SCB operation. It is only required for SPI and UART
    *             modes.
    *  \param uartEnableMask: enables TX or RX direction and RTS and CTS signals.
    *
    *******************************************************************************/
    void Tx8_SetPins(uint32 mode, uint32 subMode, uint32 uartEnableMask)
    {
        uint32 pinsDm[Tx8_SCB_PINS_NUMBER];
        uint32 i;
        
    #if (!Tx8_CY_SCBIP_V1)
        uint32 pinsInBuf = 0u;
    #endif /* (!Tx8_CY_SCBIP_V1) */
        
        uint32 hsiomSel[Tx8_SCB_PINS_NUMBER] = 
        {
            Tx8_RX_SCL_MOSI_HSIOM_SEL_GPIO,
            Tx8_TX_SDA_MISO_HSIOM_SEL_GPIO,
            0u,
            0u,
            0u,
            0u,
            0u,
        };

    #if (Tx8_CY_SCBIP_V1)
        /* Supress compiler warning. */
        if ((0u == subMode) || (0u == uartEnableMask))
        {
        }
    #endif /* (Tx8_CY_SCBIP_V1) */

        /* Set default HSIOM to GPIO and Drive Mode to Analog Hi-Z */
        for (i = 0u; i < Tx8_SCB_PINS_NUMBER; i++)
        {
            pinsDm[i] = Tx8_PIN_DM_ALG_HIZ;
        }

        if ((Tx8_SCB_MODE_I2C   == mode) ||
            (Tx8_SCB_MODE_EZI2C == mode))
        {
        #if (Tx8_RX_SCL_MOSI_PIN)
            hsiomSel[Tx8_RX_SCL_MOSI_PIN_INDEX] = Tx8_RX_SCL_MOSI_HSIOM_SEL_I2C;
            pinsDm  [Tx8_RX_SCL_MOSI_PIN_INDEX] = Tx8_PIN_DM_OD_LO;
        #elif (Tx8_RX_WAKE_SCL_MOSI_PIN)
            hsiomSel[Tx8_RX_WAKE_SCL_MOSI_PIN_INDEX] = Tx8_RX_WAKE_SCL_MOSI_HSIOM_SEL_I2C;
            pinsDm  [Tx8_RX_WAKE_SCL_MOSI_PIN_INDEX] = Tx8_PIN_DM_OD_LO;
        #else
        #endif /* (Tx8_RX_SCL_MOSI_PIN) */
        
        #if (Tx8_TX_SDA_MISO_PIN)
            hsiomSel[Tx8_TX_SDA_MISO_PIN_INDEX] = Tx8_TX_SDA_MISO_HSIOM_SEL_I2C;
            pinsDm  [Tx8_TX_SDA_MISO_PIN_INDEX] = Tx8_PIN_DM_OD_LO;
        #endif /* (Tx8_TX_SDA_MISO_PIN) */
        }
    #if (!Tx8_CY_SCBIP_V1)
        else if (Tx8_SCB_MODE_SPI == mode)
        {
        #if (Tx8_RX_SCL_MOSI_PIN)
            hsiomSel[Tx8_RX_SCL_MOSI_PIN_INDEX] = Tx8_RX_SCL_MOSI_HSIOM_SEL_SPI;
        #elif (Tx8_RX_WAKE_SCL_MOSI_PIN)
            hsiomSel[Tx8_RX_WAKE_SCL_MOSI_PIN_INDEX] = Tx8_RX_WAKE_SCL_MOSI_HSIOM_SEL_SPI;
        #else
        #endif /* (Tx8_RX_SCL_MOSI_PIN) */
        
        #if (Tx8_TX_SDA_MISO_PIN)
            hsiomSel[Tx8_TX_SDA_MISO_PIN_INDEX] = Tx8_TX_SDA_MISO_HSIOM_SEL_SPI;
        #endif /* (Tx8_TX_SDA_MISO_PIN) */
        
        #if (Tx8_SCLK_PIN)
            hsiomSel[Tx8_SCLK_PIN_INDEX] = Tx8_SCLK_HSIOM_SEL_SPI;
        #endif /* (Tx8_SCLK_PIN) */

            if (Tx8_SPI_SLAVE == subMode)
            {
                /* Slave */
                pinsDm[Tx8_RX_SCL_MOSI_PIN_INDEX] = Tx8_PIN_DM_DIG_HIZ;
                pinsDm[Tx8_TX_SDA_MISO_PIN_INDEX] = Tx8_PIN_DM_STRONG;
                pinsDm[Tx8_SCLK_PIN_INDEX] = Tx8_PIN_DM_DIG_HIZ;

            #if (Tx8_SS0_PIN)
                /* Only SS0 is valid choice for Slave */
                hsiomSel[Tx8_SS0_PIN_INDEX] = Tx8_SS0_HSIOM_SEL_SPI;
                pinsDm  [Tx8_SS0_PIN_INDEX] = Tx8_PIN_DM_DIG_HIZ;
            #endif /* (Tx8_SS0_PIN) */

            #if (Tx8_TX_SDA_MISO_PIN)
                /* Disable input buffer */
                 pinsInBuf |= Tx8_TX_SDA_MISO_PIN_MASK;
            #endif /* (Tx8_TX_SDA_MISO_PIN) */
            }
            else 
            {
                /* (Master) */
                pinsDm[Tx8_RX_SCL_MOSI_PIN_INDEX] = Tx8_PIN_DM_STRONG;
                pinsDm[Tx8_TX_SDA_MISO_PIN_INDEX] = Tx8_PIN_DM_DIG_HIZ;
                pinsDm[Tx8_SCLK_PIN_INDEX] = Tx8_PIN_DM_STRONG;

            #if (Tx8_SS0_PIN)
                hsiomSel [Tx8_SS0_PIN_INDEX] = Tx8_SS0_HSIOM_SEL_SPI;
                pinsDm   [Tx8_SS0_PIN_INDEX] = Tx8_PIN_DM_STRONG;
                pinsInBuf |= Tx8_SS0_PIN_MASK;
            #endif /* (Tx8_SS0_PIN) */

            #if (Tx8_SS1_PIN)
                hsiomSel [Tx8_SS1_PIN_INDEX] = Tx8_SS1_HSIOM_SEL_SPI;
                pinsDm   [Tx8_SS1_PIN_INDEX] = Tx8_PIN_DM_STRONG;
                pinsInBuf |= Tx8_SS1_PIN_MASK;
            #endif /* (Tx8_SS1_PIN) */

            #if (Tx8_SS2_PIN)
                hsiomSel [Tx8_SS2_PIN_INDEX] = Tx8_SS2_HSIOM_SEL_SPI;
                pinsDm   [Tx8_SS2_PIN_INDEX] = Tx8_PIN_DM_STRONG;
                pinsInBuf |= Tx8_SS2_PIN_MASK;
            #endif /* (Tx8_SS2_PIN) */

            #if (Tx8_SS3_PIN)
                hsiomSel [Tx8_SS3_PIN_INDEX] = Tx8_SS3_HSIOM_SEL_SPI;
                pinsDm   [Tx8_SS3_PIN_INDEX] = Tx8_PIN_DM_STRONG;
                pinsInBuf |= Tx8_SS3_PIN_MASK;
            #endif /* (Tx8_SS3_PIN) */

                /* Disable input buffers */
            #if (Tx8_RX_SCL_MOSI_PIN)
                pinsInBuf |= Tx8_RX_SCL_MOSI_PIN_MASK;
            #elif (Tx8_RX_WAKE_SCL_MOSI_PIN)
                pinsInBuf |= Tx8_RX_WAKE_SCL_MOSI_PIN_MASK;
            #else
            #endif /* (Tx8_RX_SCL_MOSI_PIN) */

            #if (Tx8_SCLK_PIN)
                pinsInBuf |= Tx8_SCLK_PIN_MASK;
            #endif /* (Tx8_SCLK_PIN) */
            }
        }
        else /* UART */
        {
            if (Tx8_UART_MODE_SMARTCARD == subMode)
            {
                /* SmartCard */
            #if (Tx8_TX_SDA_MISO_PIN)
                hsiomSel[Tx8_TX_SDA_MISO_PIN_INDEX] = Tx8_TX_SDA_MISO_HSIOM_SEL_UART;
                pinsDm  [Tx8_TX_SDA_MISO_PIN_INDEX] = Tx8_PIN_DM_OD_LO;
            #endif /* (Tx8_TX_SDA_MISO_PIN) */
            }
            else /* Standard or IrDA */
            {
                if (0u != (Tx8_UART_RX_PIN_ENABLE & uartEnableMask))
                {
                #if (Tx8_RX_SCL_MOSI_PIN)
                    hsiomSel[Tx8_RX_SCL_MOSI_PIN_INDEX] = Tx8_RX_SCL_MOSI_HSIOM_SEL_UART;
                    pinsDm  [Tx8_RX_SCL_MOSI_PIN_INDEX] = Tx8_PIN_DM_DIG_HIZ;
                #elif (Tx8_RX_WAKE_SCL_MOSI_PIN)
                    hsiomSel[Tx8_RX_WAKE_SCL_MOSI_PIN_INDEX] = Tx8_RX_WAKE_SCL_MOSI_HSIOM_SEL_UART;
                    pinsDm  [Tx8_RX_WAKE_SCL_MOSI_PIN_INDEX] = Tx8_PIN_DM_DIG_HIZ;
                #else
                #endif /* (Tx8_RX_SCL_MOSI_PIN) */
                }

                if (0u != (Tx8_UART_TX_PIN_ENABLE & uartEnableMask))
                {
                #if (Tx8_TX_SDA_MISO_PIN)
                    hsiomSel[Tx8_TX_SDA_MISO_PIN_INDEX] = Tx8_TX_SDA_MISO_HSIOM_SEL_UART;
                    pinsDm  [Tx8_TX_SDA_MISO_PIN_INDEX] = Tx8_PIN_DM_STRONG;
                    
                    /* Disable input buffer */
                    pinsInBuf |= Tx8_TX_SDA_MISO_PIN_MASK;
                #endif /* (Tx8_TX_SDA_MISO_PIN) */
                }

            #if !(Tx8_CY_SCBIP_V0 || Tx8_CY_SCBIP_V1)
                if (Tx8_UART_MODE_STD == subMode)
                {
                    if (0u != (Tx8_UART_CTS_PIN_ENABLE & uartEnableMask))
                    {
                        /* CTS input is multiplexed with SCLK */
                    #if (Tx8_SCLK_PIN)
                        hsiomSel[Tx8_SCLK_PIN_INDEX] = Tx8_SCLK_HSIOM_SEL_UART;
                        pinsDm  [Tx8_SCLK_PIN_INDEX] = Tx8_PIN_DM_DIG_HIZ;
                    #endif /* (Tx8_SCLK_PIN) */
                    }

                    if (0u != (Tx8_UART_RTS_PIN_ENABLE & uartEnableMask))
                    {
                        /* RTS output is multiplexed with SS0 */
                    #if (Tx8_SS0_PIN)
                        hsiomSel[Tx8_SS0_PIN_INDEX] = Tx8_SS0_HSIOM_SEL_UART;
                        pinsDm  [Tx8_SS0_PIN_INDEX] = Tx8_PIN_DM_STRONG;
                        
                        /* Disable input buffer */
                        pinsInBuf |= Tx8_SS0_PIN_MASK;
                    #endif /* (Tx8_SS0_PIN) */
                    }
                }
            #endif /* !(Tx8_CY_SCBIP_V0 || Tx8_CY_SCBIP_V1) */
            }
        }
    #endif /* (!Tx8_CY_SCBIP_V1) */

    /* Configure pins: set HSIOM, DM and InputBufEnable */
    /* Note: the DR register settings do not effect the pin output if HSIOM is other than GPIO */

    #if (Tx8_RX_SCL_MOSI_PIN)
        Tx8_SET_HSIOM_SEL(Tx8_RX_SCL_MOSI_HSIOM_REG,
                                       Tx8_RX_SCL_MOSI_HSIOM_MASK,
                                       Tx8_RX_SCL_MOSI_HSIOM_POS,
                                        hsiomSel[Tx8_RX_SCL_MOSI_PIN_INDEX]);

        Tx8_uart_rx_i2c_scl_spi_mosi_SetDriveMode((uint8) pinsDm[Tx8_RX_SCL_MOSI_PIN_INDEX]);

        #if (!Tx8_CY_SCBIP_V1)
            Tx8_SET_INP_DIS(Tx8_uart_rx_i2c_scl_spi_mosi_INP_DIS,
                                         Tx8_uart_rx_i2c_scl_spi_mosi_MASK,
                                         (0u != (pinsInBuf & Tx8_RX_SCL_MOSI_PIN_MASK)));
        #endif /* (!Tx8_CY_SCBIP_V1) */
    
    #elif (Tx8_RX_WAKE_SCL_MOSI_PIN)
        Tx8_SET_HSIOM_SEL(Tx8_RX_WAKE_SCL_MOSI_HSIOM_REG,
                                       Tx8_RX_WAKE_SCL_MOSI_HSIOM_MASK,
                                       Tx8_RX_WAKE_SCL_MOSI_HSIOM_POS,
                                       hsiomSel[Tx8_RX_WAKE_SCL_MOSI_PIN_INDEX]);

        Tx8_uart_rx_wake_i2c_scl_spi_mosi_SetDriveMode((uint8)
                                                               pinsDm[Tx8_RX_WAKE_SCL_MOSI_PIN_INDEX]);

        Tx8_SET_INP_DIS(Tx8_uart_rx_wake_i2c_scl_spi_mosi_INP_DIS,
                                     Tx8_uart_rx_wake_i2c_scl_spi_mosi_MASK,
                                     (0u != (pinsInBuf & Tx8_RX_WAKE_SCL_MOSI_PIN_MASK)));

         /* Set interrupt on falling edge */
        Tx8_SET_INCFG_TYPE(Tx8_RX_WAKE_SCL_MOSI_INTCFG_REG,
                                        Tx8_RX_WAKE_SCL_MOSI_INTCFG_TYPE_MASK,
                                        Tx8_RX_WAKE_SCL_MOSI_INTCFG_TYPE_POS,
                                        Tx8_INTCFG_TYPE_FALLING_EDGE);
    #else
    #endif /* (Tx8_RX_WAKE_SCL_MOSI_PIN) */

    #if (Tx8_TX_SDA_MISO_PIN)
        Tx8_SET_HSIOM_SEL(Tx8_TX_SDA_MISO_HSIOM_REG,
                                       Tx8_TX_SDA_MISO_HSIOM_MASK,
                                       Tx8_TX_SDA_MISO_HSIOM_POS,
                                        hsiomSel[Tx8_TX_SDA_MISO_PIN_INDEX]);

        Tx8_uart_tx_i2c_sda_spi_miso_SetDriveMode((uint8) pinsDm[Tx8_TX_SDA_MISO_PIN_INDEX]);

    #if (!Tx8_CY_SCBIP_V1)
        Tx8_SET_INP_DIS(Tx8_uart_tx_i2c_sda_spi_miso_INP_DIS,
                                     Tx8_uart_tx_i2c_sda_spi_miso_MASK,
                                    (0u != (pinsInBuf & Tx8_TX_SDA_MISO_PIN_MASK)));
    #endif /* (!Tx8_CY_SCBIP_V1) */
    #endif /* (Tx8_RX_SCL_MOSI_PIN) */

    #if (Tx8_SCLK_PIN)
        Tx8_SET_HSIOM_SEL(Tx8_SCLK_HSIOM_REG,
                                       Tx8_SCLK_HSIOM_MASK,
                                       Tx8_SCLK_HSIOM_POS,
                                       hsiomSel[Tx8_SCLK_PIN_INDEX]);

        Tx8_spi_sclk_SetDriveMode((uint8) pinsDm[Tx8_SCLK_PIN_INDEX]);

        Tx8_SET_INP_DIS(Tx8_spi_sclk_INP_DIS,
                                     Tx8_spi_sclk_MASK,
                                     (0u != (pinsInBuf & Tx8_SCLK_PIN_MASK)));
    #endif /* (Tx8_SCLK_PIN) */

    #if (Tx8_SS0_PIN)
        Tx8_SET_HSIOM_SEL(Tx8_SS0_HSIOM_REG,
                                       Tx8_SS0_HSIOM_MASK,
                                       Tx8_SS0_HSIOM_POS,
                                       hsiomSel[Tx8_SS0_PIN_INDEX]);

        Tx8_spi_ss0_SetDriveMode((uint8) pinsDm[Tx8_SS0_PIN_INDEX]);

        Tx8_SET_INP_DIS(Tx8_spi_ss0_INP_DIS,
                                     Tx8_spi_ss0_MASK,
                                     (0u != (pinsInBuf & Tx8_SS0_PIN_MASK)));
    #endif /* (Tx8_SS0_PIN) */

    #if (Tx8_SS1_PIN)
        Tx8_SET_HSIOM_SEL(Tx8_SS1_HSIOM_REG,
                                       Tx8_SS1_HSIOM_MASK,
                                       Tx8_SS1_HSIOM_POS,
                                       hsiomSel[Tx8_SS1_PIN_INDEX]);

        Tx8_spi_ss1_SetDriveMode((uint8) pinsDm[Tx8_SS1_PIN_INDEX]);

        Tx8_SET_INP_DIS(Tx8_spi_ss1_INP_DIS,
                                     Tx8_spi_ss1_MASK,
                                     (0u != (pinsInBuf & Tx8_SS1_PIN_MASK)));
    #endif /* (Tx8_SS1_PIN) */

    #if (Tx8_SS2_PIN)
        Tx8_SET_HSIOM_SEL(Tx8_SS2_HSIOM_REG,
                                       Tx8_SS2_HSIOM_MASK,
                                       Tx8_SS2_HSIOM_POS,
                                       hsiomSel[Tx8_SS2_PIN_INDEX]);

        Tx8_spi_ss2_SetDriveMode((uint8) pinsDm[Tx8_SS2_PIN_INDEX]);

        Tx8_SET_INP_DIS(Tx8_spi_ss2_INP_DIS,
                                     Tx8_spi_ss2_MASK,
                                     (0u != (pinsInBuf & Tx8_SS2_PIN_MASK)));
    #endif /* (Tx8_SS2_PIN) */

    #if (Tx8_SS3_PIN)
        Tx8_SET_HSIOM_SEL(Tx8_SS3_HSIOM_REG,
                                       Tx8_SS3_HSIOM_MASK,
                                       Tx8_SS3_HSIOM_POS,
                                       hsiomSel[Tx8_SS3_PIN_INDEX]);

        Tx8_spi_ss3_SetDriveMode((uint8) pinsDm[Tx8_SS3_PIN_INDEX]);

        Tx8_SET_INP_DIS(Tx8_spi_ss3_INP_DIS,
                                     Tx8_spi_ss3_MASK,
                                     (0u != (pinsInBuf & Tx8_SS3_PIN_MASK)));
    #endif /* (Tx8_SS3_PIN) */
    }

#endif /* (Tx8_SCB_MODE_UNCONFIG_CONST_CFG) */


#if (Tx8_CY_SCBIP_V0 || Tx8_CY_SCBIP_V1)
    /*******************************************************************************
    * Function Name: Tx8_I2CSlaveNackGeneration
    ****************************************************************************//**
    *
    *  Sets command to generate NACK to the address or data.
    *
    *******************************************************************************/
    void Tx8_I2CSlaveNackGeneration(void)
    {
        /* Check for EC_AM toggle condition: EC_AM and clock stretching for address are enabled */
        if ((0u != (Tx8_CTRL_REG & Tx8_CTRL_EC_AM_MODE)) &&
            (0u == (Tx8_I2C_CTRL_REG & Tx8_I2C_CTRL_S_NOT_READY_ADDR_NACK)))
        {
            /* Toggle EC_AM before NACK generation */
            Tx8_CTRL_REG &= ~Tx8_CTRL_EC_AM_MODE;
            Tx8_CTRL_REG |=  Tx8_CTRL_EC_AM_MODE;
        }

        Tx8_I2C_SLAVE_CMD_REG = Tx8_I2C_SLAVE_CMD_S_NACK;
    }
#endif /* (Tx8_CY_SCBIP_V0 || Tx8_CY_SCBIP_V1) */


/* [] END OF FILE */
