/***************************************************************************//**
* \file Tx8_BOOT.h
* \version 4.0
*
* \brief
*  This file provides constants and parameter values of the bootloader
*  communication APIs for the SCB Component.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2014-2017, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_BOOT_Tx8_H)
#define CY_SCB_BOOT_Tx8_H

#include "Tx8_PVT.h"

#if (Tx8_SCB_MODE_I2C_INC)
    #include "Tx8_I2C.h"
#endif /* (Tx8_SCB_MODE_I2C_INC) */

#if (Tx8_SCB_MODE_EZI2C_INC)
    #include "Tx8_EZI2C.h"
#endif /* (Tx8_SCB_MODE_EZI2C_INC) */

#if (Tx8_SCB_MODE_SPI_INC || Tx8_SCB_MODE_UART_INC)
    #include "Tx8_SPI_UART.h"
#endif /* (Tx8_SCB_MODE_SPI_INC || Tx8_SCB_MODE_UART_INC) */


/***************************************
*  Conditional Compilation Parameters
****************************************/

/* Bootloader communication interface enable */
#define Tx8_BTLDR_COMM_ENABLED ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Tx8) || \
                                             (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

/* Enable I2C bootloader communication */
#if (Tx8_SCB_MODE_I2C_INC)
    #define Tx8_I2C_BTLDR_COMM_ENABLED     (Tx8_BTLDR_COMM_ENABLED && \
                                                            (Tx8_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             Tx8_I2C_SLAVE_CONST))
#else
     #define Tx8_I2C_BTLDR_COMM_ENABLED    (0u)
#endif /* (Tx8_SCB_MODE_I2C_INC) */

/* EZI2C does not support bootloader communication. Provide empty APIs */
#if (Tx8_SCB_MODE_EZI2C_INC)
    #define Tx8_EZI2C_BTLDR_COMM_ENABLED   (Tx8_BTLDR_COMM_ENABLED && \
                                                         Tx8_SCB_MODE_UNCONFIG_CONST_CFG)
#else
    #define Tx8_EZI2C_BTLDR_COMM_ENABLED   (0u)
#endif /* (Tx8_EZI2C_BTLDR_COMM_ENABLED) */

/* Enable SPI bootloader communication */
#if (Tx8_SCB_MODE_SPI_INC)
    #define Tx8_SPI_BTLDR_COMM_ENABLED     (Tx8_BTLDR_COMM_ENABLED && \
                                                            (Tx8_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             Tx8_SPI_SLAVE_CONST))
#else
        #define Tx8_SPI_BTLDR_COMM_ENABLED (0u)
#endif /* (Tx8_SPI_BTLDR_COMM_ENABLED) */

/* Enable UART bootloader communication */
#if (Tx8_SCB_MODE_UART_INC)
       #define Tx8_UART_BTLDR_COMM_ENABLED    (Tx8_BTLDR_COMM_ENABLED && \
                                                            (Tx8_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             (Tx8_UART_RX_DIRECTION && \
                                                              Tx8_UART_TX_DIRECTION)))
#else
     #define Tx8_UART_BTLDR_COMM_ENABLED   (0u)
#endif /* (Tx8_UART_BTLDR_COMM_ENABLED) */

/* Enable bootloader communication */
#define Tx8_BTLDR_COMM_MODE_ENABLED    (Tx8_I2C_BTLDR_COMM_ENABLED   || \
                                                     Tx8_SPI_BTLDR_COMM_ENABLED   || \
                                                     Tx8_EZI2C_BTLDR_COMM_ENABLED || \
                                                     Tx8_UART_BTLDR_COMM_ENABLED)


/***************************************
*        Function Prototypes
***************************************/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Tx8_I2C_BTLDR_COMM_ENABLED)
    /* I2C Bootloader physical layer functions */
    void Tx8_I2CCyBtldrCommStart(void);
    void Tx8_I2CCyBtldrCommStop (void);
    void Tx8_I2CCyBtldrCommReset(void);
    cystatus Tx8_I2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Tx8_I2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map I2C specific bootloader communication APIs to SCB specific APIs */
    #if (Tx8_SCB_MODE_I2C_CONST_CFG)
        #define Tx8_CyBtldrCommStart   Tx8_I2CCyBtldrCommStart
        #define Tx8_CyBtldrCommStop    Tx8_I2CCyBtldrCommStop
        #define Tx8_CyBtldrCommReset   Tx8_I2CCyBtldrCommReset
        #define Tx8_CyBtldrCommRead    Tx8_I2CCyBtldrCommRead
        #define Tx8_CyBtldrCommWrite   Tx8_I2CCyBtldrCommWrite
    #endif /* (Tx8_SCB_MODE_I2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Tx8_I2C_BTLDR_COMM_ENABLED) */


#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Tx8_EZI2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void Tx8_EzI2CCyBtldrCommStart(void);
    void Tx8_EzI2CCyBtldrCommStop (void);
    void Tx8_EzI2CCyBtldrCommReset(void);
    cystatus Tx8_EzI2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Tx8_EzI2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map EZI2C specific bootloader communication APIs to SCB specific APIs */
    #if (Tx8_SCB_MODE_EZI2C_CONST_CFG)
        #define Tx8_CyBtldrCommStart   Tx8_EzI2CCyBtldrCommStart
        #define Tx8_CyBtldrCommStop    Tx8_EzI2CCyBtldrCommStop
        #define Tx8_CyBtldrCommReset   Tx8_EzI2CCyBtldrCommReset
        #define Tx8_CyBtldrCommRead    Tx8_EzI2CCyBtldrCommRead
        #define Tx8_CyBtldrCommWrite   Tx8_EzI2CCyBtldrCommWrite
    #endif /* (Tx8_SCB_MODE_EZI2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Tx8_EZI2C_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Tx8_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void Tx8_SpiCyBtldrCommStart(void);
    void Tx8_SpiCyBtldrCommStop (void);
    void Tx8_SpiCyBtldrCommReset(void);
    cystatus Tx8_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Tx8_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map SPI specific bootloader communication APIs to SCB specific APIs */
    #if (Tx8_SCB_MODE_SPI_CONST_CFG)
        #define Tx8_CyBtldrCommStart   Tx8_SpiCyBtldrCommStart
        #define Tx8_CyBtldrCommStop    Tx8_SpiCyBtldrCommStop
        #define Tx8_CyBtldrCommReset   Tx8_SpiCyBtldrCommReset
        #define Tx8_CyBtldrCommRead    Tx8_SpiCyBtldrCommRead
        #define Tx8_CyBtldrCommWrite   Tx8_SpiCyBtldrCommWrite
    #endif /* (Tx8_SCB_MODE_SPI_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Tx8_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Tx8_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void Tx8_UartCyBtldrCommStart(void);
    void Tx8_UartCyBtldrCommStop (void);
    void Tx8_UartCyBtldrCommReset(void);
    cystatus Tx8_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Tx8_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map UART specific bootloader communication APIs to SCB specific APIs */
    #if (Tx8_SCB_MODE_UART_CONST_CFG)
        #define Tx8_CyBtldrCommStart   Tx8_UartCyBtldrCommStart
        #define Tx8_CyBtldrCommStop    Tx8_UartCyBtldrCommStop
        #define Tx8_CyBtldrCommReset   Tx8_UartCyBtldrCommReset
        #define Tx8_CyBtldrCommRead    Tx8_UartCyBtldrCommRead
        #define Tx8_CyBtldrCommWrite   Tx8_UartCyBtldrCommWrite
    #endif /* (Tx8_SCB_MODE_UART_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Tx8_UART_BTLDR_COMM_ENABLED) */

/**
* \addtogroup group_bootloader
* @{
*/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Tx8_BTLDR_COMM_ENABLED)
    #if (Tx8_SCB_MODE_UNCONFIG_CONST_CFG)
        /* Bootloader physical layer functions */
        void Tx8_CyBtldrCommStart(void);
        void Tx8_CyBtldrCommStop (void);
        void Tx8_CyBtldrCommReset(void);
        cystatus Tx8_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
        cystatus Tx8_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    #endif /* (Tx8_SCB_MODE_UNCONFIG_CONST_CFG) */

    /* Map SCB specific bootloader communication APIs to common APIs */
    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Tx8)
        #define CyBtldrCommStart    Tx8_CyBtldrCommStart
        #define CyBtldrCommStop     Tx8_CyBtldrCommStop
        #define CyBtldrCommReset    Tx8_CyBtldrCommReset
        #define CyBtldrCommWrite    Tx8_CyBtldrCommWrite
        #define CyBtldrCommRead     Tx8_CyBtldrCommRead
    #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Tx8) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Tx8_BTLDR_COMM_ENABLED) */

/** @} group_bootloader */

/***************************************
*           API Constants
***************************************/

/* Timeout unit in milliseconds */
#define Tx8_WAIT_1_MS  (1u)

/* Return number of bytes to copy into bootloader buffer */
#define Tx8_BYTES_TO_COPY(actBufSize, bufSize) \
                            ( ((uint32)(actBufSize) < (uint32)(bufSize)) ? \
                                ((uint32) (actBufSize)) : ((uint32) (bufSize)) )

/* Size of Read/Write buffers for I2C bootloader  */
#define Tx8_I2C_BTLDR_SIZEOF_READ_BUFFER   (64u)
#define Tx8_I2C_BTLDR_SIZEOF_WRITE_BUFFER  (64u)

/* Byte to byte time interval: calculated basing on current component
* data rate configuration, can be defined in project if required.
*/
#ifndef Tx8_SPI_BYTE_TO_BYTE
    #define Tx8_SPI_BYTE_TO_BYTE   (160u)
#endif

/* Byte to byte time interval: calculated basing on current component
* baud rate configuration, can be defined in the project if required.
*/
#ifndef Tx8_UART_BYTE_TO_BYTE
    #define Tx8_UART_BYTE_TO_BYTE  (171u)
#endif /* Tx8_UART_BYTE_TO_BYTE */

#endif /* (CY_SCB_BOOT_Tx8_H) */


/* [] END OF FILE */
