/***************************************************************************//**
* \file .h
* \version 4.0
*
* \brief
*  This private file provides constants and parameter values for the
*  SCB Component.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2017, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PVT_Tx8_H)
#define CY_SCB_PVT_Tx8_H

#include "Tx8.h"


/***************************************
*     Private Function Prototypes
***************************************/

/* APIs to service INTR_I2C_EC register */
#define Tx8_SetI2CExtClkInterruptMode(interruptMask) Tx8_WRITE_INTR_I2C_EC_MASK(interruptMask)
#define Tx8_ClearI2CExtClkInterruptSource(interruptMask) Tx8_CLEAR_INTR_I2C_EC(interruptMask)
#define Tx8_GetI2CExtClkInterruptSource()                (Tx8_INTR_I2C_EC_REG)
#define Tx8_GetI2CExtClkInterruptMode()                  (Tx8_INTR_I2C_EC_MASK_REG)
#define Tx8_GetI2CExtClkInterruptSourceMasked()          (Tx8_INTR_I2C_EC_MASKED_REG)

#if (!Tx8_CY_SCBIP_V1)
    /* APIs to service INTR_SPI_EC register */
    #define Tx8_SetSpiExtClkInterruptMode(interruptMask) \
                                                                Tx8_WRITE_INTR_SPI_EC_MASK(interruptMask)
    #define Tx8_ClearSpiExtClkInterruptSource(interruptMask) \
                                                                Tx8_CLEAR_INTR_SPI_EC(interruptMask)
    #define Tx8_GetExtSpiClkInterruptSource()                 (Tx8_INTR_SPI_EC_REG)
    #define Tx8_GetExtSpiClkInterruptMode()                   (Tx8_INTR_SPI_EC_MASK_REG)
    #define Tx8_GetExtSpiClkInterruptSourceMasked()           (Tx8_INTR_SPI_EC_MASKED_REG)
#endif /* (!Tx8_CY_SCBIP_V1) */

#if(Tx8_SCB_MODE_UNCONFIG_CONST_CFG)
    extern void Tx8_SetPins(uint32 mode, uint32 subMode, uint32 uartEnableMask);
#endif /* (Tx8_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Vars with External Linkage
***************************************/

#if (Tx8_SCB_IRQ_INTERNAL)
#if !defined (CY_REMOVE_Tx8_CUSTOM_INTR_HANDLER)
    extern cyisraddress Tx8_customIntrHandler;
#endif /* !defined (CY_REMOVE_Tx8_CUSTOM_INTR_HANDLER) */
#endif /* (Tx8_SCB_IRQ_INTERNAL) */

extern Tx8_BACKUP_STRUCT Tx8_backup;

#if(Tx8_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common configuration variables */
    extern uint8 Tx8_scbMode;
    extern uint8 Tx8_scbEnableWake;
    extern uint8 Tx8_scbEnableIntr;

    /* I2C configuration variables */
    extern uint8 Tx8_mode;
    extern uint8 Tx8_acceptAddr;

    /* SPI/UART configuration variables */
    extern volatile uint8 * Tx8_rxBuffer;
    extern uint8   Tx8_rxDataBits;
    extern uint32  Tx8_rxBufferSize;

    extern volatile uint8 * Tx8_txBuffer;
    extern uint8   Tx8_txDataBits;
    extern uint32  Tx8_txBufferSize;

    /* EZI2C configuration variables */
    extern uint8 Tx8_numberOfAddr;
    extern uint8 Tx8_subAddrSize;
#endif /* (Tx8_SCB_MODE_UNCONFIG_CONST_CFG) */

#if (! (Tx8_SCB_MODE_I2C_CONST_CFG || \
        Tx8_SCB_MODE_EZI2C_CONST_CFG))
    extern uint16 Tx8_IntrTxMask;
#endif /* (! (Tx8_SCB_MODE_I2C_CONST_CFG || \
              Tx8_SCB_MODE_EZI2C_CONST_CFG)) */


/***************************************
*        Conditional Macro
****************************************/

#if(Tx8_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Defines run time operation mode */
    #define Tx8_SCB_MODE_I2C_RUNTM_CFG     (Tx8_SCB_MODE_I2C      == Tx8_scbMode)
    #define Tx8_SCB_MODE_SPI_RUNTM_CFG     (Tx8_SCB_MODE_SPI      == Tx8_scbMode)
    #define Tx8_SCB_MODE_UART_RUNTM_CFG    (Tx8_SCB_MODE_UART     == Tx8_scbMode)
    #define Tx8_SCB_MODE_EZI2C_RUNTM_CFG   (Tx8_SCB_MODE_EZI2C    == Tx8_scbMode)
    #define Tx8_SCB_MODE_UNCONFIG_RUNTM_CFG \
                                                        (Tx8_SCB_MODE_UNCONFIG == Tx8_scbMode)

    /* Defines wakeup enable */
    #define Tx8_SCB_WAKE_ENABLE_CHECK       (0u != Tx8_scbEnableWake)
#endif /* (Tx8_SCB_MODE_UNCONFIG_CONST_CFG) */

/* Defines maximum number of SCB pins */
#if (!Tx8_CY_SCBIP_V1)
    #define Tx8_SCB_PINS_NUMBER    (7u)
#else
    #define Tx8_SCB_PINS_NUMBER    (2u)
#endif /* (!Tx8_CY_SCBIP_V1) */

#endif /* (CY_SCB_PVT_Tx8_H) */


/* [] END OF FILE */
